%CIRCAD VERSION 3.8 -- HYPERTEXT REFERENCE MANUAL
%
% This file contains the basic reference manual frames that are used by the 
% hypertext access system.
%
% The file is encoded using a simplified version of TEX macros.
%
% The following built-in functions are supported:
%
%  \L{#1}        Single line, left justified.  This function is used to 
%                construct columns of data.  Its text string parameter can 
%                contain any combination of the following hypertext functions.
%  \M{#1}        Message to be displayed on the status line.  As a practical 
%                matter, each display frame must contain exactly one message 
%                declaration.
%  \T{#1}        Title of normal display frame.  At the present time this 
%                function serves no purpose, other than to display its text 
%                string parameter in bold face green type.
%  \C{#1}        Title of error alert display frame.  At the present time, this 
%                function serves no purpose, other than to display its text 
%                string parameter in bold face red type.
%  \B{#1}        Boldface text string.  The text string parameter to this 
%                function is displayed in bold face black type.  It is used 
%                to place emphasis on a word or phrase.
%  \S{#1}        Selection text string.  The text string parameter to this 
%                function is displayed in bold face blue type.  A windows 
%                selection box is created to exactly enclose the text.  When 
%                selected, the entire text string will be re-submitted to the 
%                hypertext frame search subroutine.
%  \R{#1}        Replacement string for selection text.  If used, this function 
%                must immediately follow the selection function it is to act 
%                upon.  Although its text string parameter will not be 
%                displayed, it will be used in preference to the displayed text 
%                for re-submission to the hypertext frame search subroutine.
%  \0~9          Decimal number definition of a single character.
%
%
% The following special characters are supported:
%
%  \ backslash   Logical escape.  Precedes all functions.
%  % percent     Logical end-of-line.  All following data are ignored.
%  ~ tilde       Keep space.  Used for vertical alignment.
%  & ampersand   Logical tab.  Used for vertical alignment.
%  { left brace  Marks the start of a group.
%  } right brace Marks the close of a group.
%  @ at          Marks the name of a frame (column one only).
%
%  The above listed special characters can be literalized by 
%  preceding them with a backslash (\) character.
%
%
%  The following spacing MUST be observed:
%
%  Exactly one blank line is needed between paragraphs.
%
%  Exactly two blank lines are needed between frames.
%
%
Welcome to the \S{CIRCAD} interactive context sensitive hypertext 
reference manual.  Detailed information is available on selection 
menus, dialog boxes, and error messages.

You may access this manual at any time by pressing the 
\S{<center mouse>} button or \S{<F12>} on the keyboard.  Once 
within the hypertext sub-system, you may receive additional 
information on related topics by selecting any of the text strings 
that are displayed in bold face blue type.  Also, you may jump to 
an entirely unrelated subject by selecting one of the function 
buttons at the bottom of this window.

\L{~}
Do you have a three button mouse?

\S{YES, 3 buttons}%
\R{Three button mouse} &&%
\S{NO, only 2 buttons}%
\R{Two button mouse}


@Three button mouse
\M{Three button mouse}
\T{Three button mouse:}

On a three button mouse, the reference manual may be accessed at any 
time by pressing the \S{<center mouse>} button.

If desired, pressing the function key \S{<F12>} on the main keyboard 
will also provide immediate access.

At this time, you may browse the manual by selecting either 
\S{Contents} or \S{Index} at the bottom of this menu.


@Two button mouse
\M{Two button mouse}
\T{Two button mouse:}

On a two button mouse, access to the reference manual is available at 
any time by pressing the function key \S{<F12>} on the keyboard.

At this time, you may browse the manual by selecting either 
\S{Contents} or \S{Index} at the bottom of this menu.


@@255
@GENERAL
@CONTENTS
@Contents
@Table of Contents
\M{Table of Contents}
Welcome to the \S{CIRCAD} interactive context sensitive hypertext 
reference manual.  Detailed information is available on selection 
menus, dialog boxes, and error messages.

You may access this manual at any time by pressing the 
\S{<center mouse>} button or \S{<F12>} on the keyboard.  Once 
within the hypertext sub-system, you may receive additional 
information on related topics by selecting any of the text 
strings that are displayed in bold face blue type.

Please select one of the following topics:

\L{\S{File functions} &&&\S{Setup functions}}
\L{\S{Place functions}&&&\S{Block functions}}
\L{\S{Grab functions}&&&\S{Netlist functions}}
\L{\S{Edit functions}&&&\S{Zoom functions}}
\L{\S{Delete functions}}


@INDEX
@Index
@Alphabetical Index
\M{Alphabetical Index}
\T{Alphabetical Index:}

\L{\S{Absolute cursor positioning}}
\L{\B{Arcs, circles, and ellipses}}
\L{  \S{Arc/circle parameters}}
\L{  \S{Delete Arc/circle}}
\L{  \S{Edit Arc/circle}}
\L{  \S{Grab Arc edge}}
\L{  \S{Grab Arc origin}}
\L{  \S{Place Arc/circle}}
\L{\S{ASCII}}
\L{\S{ASCII Extended}}
\L{\S{Auto-route}}

\L{\S{Backup directory}}
\L{\S{Backup file}}
\L{\S{Bill of Material}}
\L{\S{Block menu}}
\L{\S{BMP pixel image file}}

\L{\S{<center mouse>} \B{button}}
\L{\B{circles} --- see: Arcs}
\L{\S{Close File}}
\L{\B{Components}}
\L{  \S{Build Component}}
\L{  \S{Delete Component}}
\L{  \S{Edit Component}}
\L{  \S{Grab Component}}
\L{  \S{Krump Component}}
\L{  \S{Locate Component}}
\L{  \S{Nest Component}}
\L{  \S{Place Component}}

\L{\S{Delete menu}}
\L{\B{Draw modes}}
\L{  \S{Plotter draw modes}}
\L{  \S{Screen draw modes}}
\L{\S{driver subdirectory}}
\L{\S{DXF files}}

\L{\S{Edit menu}}
\L{\B{ellipses} --- see: Arcs}
\L{\S{<Enter>} \B{key}}
\L{\S{Erase File}}
\L{\S{<Escape>} \B{key}}
\L{\S{Exit/Quit}}
\L{\S{export filters}}

\L{\S{File backup}}
\L{\S{File menu}}
\L{\S{file naming conventions}}
\L{\S{function keys}}

\L{\S{Gerber format}}
\L{\S{Gerber plotting}}
\L{\S{Gerber plot parameters}}
\L{\S{Gerber file types}}
\L{\S{Grab menu}}

\L{\S{Hilight Net}}
\L{\S{Hilight, delete}}

\L{\S{import filters}}

\L{\S{keystroke macros}}

\L{\S{<left mouse>} \B{button}}
\L{\S{Library File}}
\L{\S{Library Setup}}
\L{\S{library subdirectory}}
\L{\S{Library View}}
\L{\B{line segments}}
\L{  \S{Delete Line}}
\L{  \S{Delete Multi-line}}
\L{  \S{Edit Line}}
\L{  \S{Grab Line}}
\L{  \S{Place Line}}

\L{\S{menu bar}}
\L{\S{Mirror View}}
\L{\S{Mirror T/B}}
\L{\S{Mirror X}}
\L{\S{Mirror Y}}
\L{\B{mouse buttons}}
\L{  \S{<center mouse>}}
\L{  \S{<left mouse>}}
\L{  \S{<right mouse>}}

\L{\S{Net Clearances}}
\L{\S{Net Scan}}
\L{\S{Netlist error log}}
\L{\S{Nets menu}}
\L{\S{New File}}
\L{\S{Next File}}

\L{\S{Open File}}
\L{\S{ortho mode}}

\L{\B{Pads}}
\L{  \S{Delete Pad}}
\L{  \S{Edit Pad}}
\L{  \S{Grab Pad}}
\L{  \S{Place Pad}}
\L{\S{PCX pixel image file}}
\L{\S{Pen plotting}}
\L{\S{Photo plotting}}
\L{\S{Place menu}}
\L{\B{plotting}}
\L{  \S{Gerber plotting}}
\L{  \S{Pen plotting}}
\L{  \S{Printer plotting}}
\L{\S{Previous File}}

\L{\S{reserved file names}}
\L{\S{<Return>} \B{key}}
\L{\S{<right mouse>} \B{button}}
\L{\S{rotation}}
\L{\S{RS-274-D}}

\L{\S{Save File}}
\L{\S{Save As ...}}
\L{\S{Setup menu}}
\L{\S{shortcut keys}}
\L{\S{snap to item}}
\L{\S{snap to position}}
\L{\S{<space bar>} \B{key}}
\L{\S{special characters}}

\L{\S{template files}}
\L{\S{template subdirectory}}
\L{\B{Text strings}}
\L{  \S{Delete Text}}
\L{  \S{Edit Text data}}
\L{  \S{Edit Text parameters}}
\L{  \S{Grab Text}}
\L{  \S{Place Text}}

\L{\B{Vertices}}
\L{  \S{Delete Vertex}}
\L{  \S{Grab Vertex}}
\L{  \S{Place Vertex}}
\L{\B{Vias}}
\L{  \S{Delete Pad/via}}
\L{  \S{Edit Pad/via}}
\L{  \S{Grab Pad/via}}
\L{  \S{Place Via}}
\L{  \S{Via parameters}}

\L{\S{Zero Point Setup}}
\L{\S{Zoom Limits Setup}}
\L{\S{Zoom menu}}


@function keys
@Function keys
\M{Function keys}
\T{Function keys:}&&(also see: \S{shortcut keys})

\L{F1 &\S{Place Line}}
\L{F2 &\S{Place Arc}}
\L{F3 &\S{Place Pad}}
\L{F4 &\S{Place Text}}
\L{F5 &\S{Place Ortho-line}}
\L{F6 &\S{Place Component}}
\L{F7 &\S{Place Via}}
\L{F8 &\S{Place Vertex}}
\L{F9 &\S{Zoom Re-draw}}
\L{F10 &\S{Zoom Re-draw}}
\L{F12 &\S{Reference Manual}}

\L{Alt F1 &\S{Grab Line}}
\L{Alt F2 &\S{Grab Arc edge}}
\L{Alt F3 &\S{Grab Pad}}
\L{Alt F4 &\S{Grab Text}}
\L{Alt F5 &\S{Grab Item}}
\L{Alt F6 &\S{Grab Component Only}}
\L{Alt F7 &\S{Grab Component}}
\L{Alt F8 &\S{Grab Vertex}}
\L{Alt F9 &\S{Insert Component}}

\L{Ctl F1 &\S{Edit Line}}
\L{Ctl F2 &\S{Edit Arc}}
\L{Ctl F3 &\S{Edit Pad}}
\L{Ctl F4 &\S{Edit Text data}}
\L{Ctl F5 &\S{Edit Text parameters}}
\L{Ctl F6 &\S{Edit Component}}
\L{Ctl F7 &\S{Locate Component}}
\L{Ctl F8 &\S{Krump Component}}
\L{Ctl F9 &\S{Snap to Item}}

\L{Shft F1 &\S{Delete Line}}
\L{Shft F2 &\S{Delete Arc}}
\L{Shft F3 &\S{Delete Pad}}
\L{Shft F4 &\S{Delete Text}}
\L{Shft F5 &\S{Delete Multi-line}}
\L{Shft F6 &\S{Delete Component}}
\L{Shft F7 &\S{Delete Grabs}}
\L{Shft F8 &\S{Delete Vertex}}


@shortcut keys
@Shortcut keys
\M{Shortcut keys}
\T{Shortcut keys:}&&(also see: \S{function keys})

\L{A &\S{Rotate n}}
\L{C &\S{Zoom Center}}
\L{H &\S{Net Hilight}}
\L{I &\S{Zoom In}}
\L{J &\S{Total Hilight}}
\L{K &\S{Scale XY}}
\L{L &\S{Select layer}}
\L{M &\S{Mirror Top/Bottom}}
\L{O &\S{Zoom Out}}
\L{R &\S{Rotate 90}}
\L{T &\S{Toggle Ortho mode}}
\L{U &\S{Rotate Upside-down}}
\L{X &\S{Mirror X}}
\L{Y &\S{Mirror Y}}
\L{W &\S{Zoom Window}}

\L{Alt B &\S{Block Rectangle}}
\L{Alt C &\S{Command line processor}}
\L{Alt F &\S{File name display}}
\L{Alt G &\S{Grid Snap}}
\L{Alt H &\S{Net Scan}}
\L{Alt J &\S{Name Net}}
\L{Alt M &\S{Alternate Pixel Image}}
\L{Alt N &\S{Next File}}
\L{Alt P &\S{Pen Plot}}
\L{Alt R &\S{Set/clear zero point}}
\L{Alt V &\S{Mirror View}}
\L{Alt W &\S{Save File}}
\L{Alt X &\S{Exit/Quit}}
\L{Alt - &\S{Previous File}}

\L{0\~9 &\S{Absolute cursor positioning}}

\L{N- &\S{Select next shallower layer}}
\L{N+ &\S{Select next deeper layer}}

\L{Alt N- &\S{Net Scan -}}
\L{Alt N+ &\S{Net Scan +}}

\L{N* &\S{Keystroke Macro playback}}
\L{Alt N* &\S{Keystroke Macro entry}}

\L{Alt 8 &\S{Snapshot file name}}
\L{Alt 9 &\S{Snapshot cursor removal}}
\L{Alt 0 &\S{Snapshot output}}


@special characters
\M{Special characters}
\T{Special characters:}

These \S{Extended ASCII} characters are available by typing 
the designated 3-digit number while holding down the \B{<ALT>} 
key.  The character will be produced when the \B{<ALT>} key 
is released.

\L{Alt (224) &\B{ Alpha}}
\L{Alt (225) &\B{ Beta}}
\L{Alt (226) &\B{ Gamma}}
\L{Alt (227) &\B{ Pi}}
\L{Alt (228) &\B{ Sigma}}
\L{Alt (229) &\B{ sigma}}
\L{Alt (230) &\B{ Mu} &&&[Also: Alt U]}
\L{Alt (233) &\B{ Theta}}
\L{Alt (234) &\B{ Omega} &&[Also: Alt O]}

\L{Alt (171) &\B{ One-half} &&[Also: Alt 2]}
\L{Alt (172) &\B{ One-fourth} &[Also: Alt 4]}
\L{Alt (241) &\B{ Plus/minus}}
\L{Alt (242) &\B{ Greater/equal}}
\L{Alt (243) &\B{ Less/equal}}
\L{Alt (246) &\B{ Divided by}}
\L{Alt (247) &\B{ Approximate}}
\L{Alt (248) &\B{ Degree}}
\L{Alt (253) &\B{ Squared}}


@<left mouse>
\M{Left mouse button}
The \T{<left mouse>} button is the "action" button for all 
functions.

If you do not have a mouse, or do not wish to use the mouse, the 
\S{<Return>} key or the \S{<Enter>} key on the keyboard will 
perform the same operation.

Related functions:
\L{\S{<center mouse>} button}
\L{\S{<right mouse>} button}


@<center mouse>
\M{Center mouse button}
The \T{<center mouse>} button is available only on three-button 
mouses.

If you have only a two-button mouse, you can simulate the center 
mouse button by pressing the \S{<F12>} key.

Related functions:
\L{\S{<left mouse>} button}
\L{\S{<right mouse>} button}


@<right mouse>
\M{Right mouse button}
The \T{<right mouse>} button is the escape button for all 
functions.

If you do not have a mouse, or do not wish to use the mouse, the 
\S{<Escape>} key on the keyboard will perform the same operation.

Related functions:
\L{\S{<left mouse>} button}
\L{\S{<center mouse>} button}


@<Return>
\M{Return key}
The \T{<Return>} key on the keyboard is the "action" key for all 
functions.

If you chose to use a mouse, the \S{<left mouse>} button will 
provide similar performance.

Related functions:
\L{\S{<Enter>} \B{key}}
\L{\S{<Escape>} \B{key}}


@<Enter>
\M{Enter key}
The \T{<Enter>} key on the keyboard is the "action" key for all 
functions.

If you chose to use a mouse, the \S{<left mouse>} button will 
provide similar performance.

Related functions:
\L{\S{<Return>} \B{key}}
\L{\S{<Escape>} \B{key}}


@<Escape>
\M{Escape key}
The \T{<Escape>} key on the keyboard can be used at any time to 
escape from the various functions and operations.

If you chose to use a mouse, the \S{<right mouse>} button will 
provide similar performance.

Related functions:
\L{\S{<Enter>} \B{key}}
\L{\S{<Return>} \B{key}}


@<space bar>
\M{Space bar}
The \T{<space bar>} on the keyboard can be used to invoke the 
\S{menu bar} at the top of the screen.

The menus can also be invoked by pressing the \S{<left mouse>} 
button when the system is in the "ground" state and no 
auto-function is in effect.


@<F12>
\M{F12 key}
The keystroke \T{<F12>} will perform the same function as the 
\S{<center mouse>} button on a three-button mouse.


@Menu
@menu bar
@Main menu bar
\M{Main menu bar}
The \T{main menu bar} may be invoked by using any of the three 
following methods.

1.~~Press \S{<space bar>} on the keyboard.

2.~~Type a key that matches one of the nine "action" characters 
that are hilighted on the main menu bar.

3.~~With no auto-function in effect, press \S{<left mouse>} or 
\S{<Enter>} on the keyboard.

Once invoked, the cursor can easily be moved throughout the menu 
selections by either using the \B{<\27>}, \B{<\26>}, \B{<\24>}, 
and \B{<\25>} keys, or by rolling the mouse about.

As each menu is displayed, a prompting message for that menu is 
provided on the status line at the bottom of the screen.


@Layer name
\M{Layer name}
\T{Layer name:}

Each of the sixteen layers should be assigned a unique layer 
name.  For layer types such as copper, mask, and silk the layer 
name should begin with the word "Top" or "Bottom".


@Line thickness
\M{Line thickness}
\T{Line thickness:}

A line can be assigned a width or thickness that can range from 
1 mil to 255 mils in one mil increments.


@Radius
\M{Arc radius}
\T{Arc radius:}

An arc, circle, or ellipse can be assigned a radius that can 
range from 1 mil to 15383 mils in one mil increments.

The radius of an ellipse refers to the major axis.  The minor 
radius is controlled by the eccentricity factor.


@Start angle
\M{Arc start angle}
\T{Arc start angle:}

An arc, circle, or ellipse can be assigned a start angle 
parameter that can range from 0 to 360 in increments of 
/128 radians, which is equal to 1.40625.


@Sweep angle
\M{Arc sweep angle}
\T{Arc sweep angle:}

An arc, circle, or ellipse can be assigned a sweep angle 
parameter that can range from 1.4 to 360 in increments of 
/128 radians, which is equal to 1.40625.


@Elliptical eccentricity
\M{Elliptical eccentricity}
\T{Elliptical eccentricity:}

An arc or a circle can be assigned an elliptical eccentricity 
parameter that can range from 1.000 to 0.004 in 0.004 increments.


@Axis angle
\M{Elliptical axis angle}
\T{Elliptical axis angle:}

An ellipse can be assigned a axis rotation angle parameter that 
can range from 0 to 360 in increments of /128 radians, which 
is equal to 1.40625.


@Pin name
\M{Pad pin name}
\T{Pad pin name:}

A pad can be assigned a pin name parameter to uniquely identify 
it from all other pads in the component.

This name can be any combination of up to 12 alpha or numeric 
characters.


@Text size
\M{Text size}
\T{Text size:}

A text string can be assigned a size parameter that can range 
from 6 mils to 762 mils in six mil increments.

This number specifies the height of a normal upper-case character.


@Rotation angle
\M{Rotation angle}
\T{Rotation angle:}

An text string can be assigned a rotational parameter that can 
range from 0 to 360 in increments of /128 radians, which is 
equal to 1.40625.


@Signal name
\M{Signal name}
\T{Signal name:}

Lines, arcs, and pads can be assigned a signal name parameter to 
logically connect a group of items into a \S{signal net}.

This name can be any combination of up to 12 alpha or numeric 
characters.


@@1
\M{No active file}
\C{No active file:}

The function you have just selected cannot be performed without 
a data file to act upon.  At the present time, no data files are 
open for editing.

To continue, you must do one of the following:

1.~~\S{Open} a data file.

2.~~Select a function that does not need an active data file.

3.~~\S{Exit} from \S{CIRCAD} and return to the operating system.


@@2
\M{File in use}
\C{File in use:}

The function that you just selected would modify the current 
data file.  This is not allowed at the present time, however, 
because the file is being processed by another task and is 
accessible in a "read only" mode for viewing but not for 
modifying.

To continue, you must do one of the following:

1.~~Refrain from using file modification functions until the 
background task completes its operation upon this file.

2.~~Select or open a different data file that if free from such 
restrictions.

3.~~Terminate the background task that is using this data file.


@@3
\M{File not found}
\C{File not found:}

This message is produced when DOS signals that the specified 
file cannot be located.  This condition is most often produced 
by an incorrect drive name or directory path.

To continue, you must escape from the current function and 
re-try with correct input data.


@@4
\M{Unrecognizable file type}
\C{Unrecognizable file type:}

The file you have selected for processing cannot be deciphered 
by any of the \S{import filters} currently available in the 
system.

Please choose a different file name or path.


@@5
\M{File is active}
\C{File is active:}

The file you have just selected for processing has already been 
opened.

Opening a file that is currently active in the system is not 
allowed and will result in an error message.

If you wish to edit or view this file, you can use either the 
\S{Next File} or \S{Previous File} functions to search for the 
desired file amongst the set of open data files.


@@6
\M{Bad file name}
\C{Bad file name:}

This message is produced when DOS signals that the specified 
file cannot be opened.  This condition is most often produced by 
an incorrect drive name or directory path.

To continue, you must escape from the current function and 
re-try with correct data.


@@7
\M{Disk/diskette is full}
\C{Disk/diskette is full:}

DOS has signaled that data cannot be written to the specified 
file.  This condition generally indicates that the target disk 
or diskette is full.  In any case, the current output file will 
be present but its data set will be incomplete.

To continue, you must escape from the current function and 
re-try the previous operation using a different drive or device.


@@10
\M{XMS/EMB memory is not available}
\C{XMS/EMB memory is not available:}

The requested function requires the use of extended memory 
(above 1MB).  The system XMS driver (in DOS) is not loaded, 
has not been enabled, or is otherwise not available for use.

The requested function cannot be performed.

This is generally not a fatal error.


@@11
\M{XMS/EMB memory is not sufficient}
\C{XMS/EMB memory is not sufficient:}

The requested function requires the use of extended memory 
(above 1MB).  The system XMS driver is not granting CIRCAD's 
request for the allocation of a section of that memory.  The 
most likely cause of this condition is insufficient extended 
memory in your computer.

If you are running in a Microsoft Windows environment, all 
available XMS/EMB memory may be allocated to other programs.  If 
this is the case, it may be possible to remedy the situation by 
establishing a \B{PIF} for CIRCAD that reserves additional memory 
from the XMS pool.

The requested function cannot be performed at this time.

This is generally not a fatal error.


@@14
\M{Unrecognizable file type}
\C{Unrecognizable file type:}

The pixel image file you have selected for processing cannot be 
deciphered by any of the \S{pixel import filters} currently 
available in the system.

Please choose a different file name or path.


@@15
\M{Scanner cannot be located}
\C{Scanner cannot be located:}

After searching the attached hardware, no supported scanning 
device can be located.

At the present time, the following scanner drivers are 
available:

\L{ 1.  Epson scanner on bi-directional LPT2.}


@@16
\M{Scanner is not responding}
\C{Scanner is not responding:}

The selected scanning device is not acknowledging CIRCAD's requests 
for data or status information.

The most likely cause of this condition is that the scanner's power 
switch is not turned on.

Apply power to the scanner and retry your request.


@Memory is full
\M{Memory is full}
\C{Memory is full:}

At this time, you must use the \S{Close File} function to 
close one or  more of the active files, thus freeing up 
their memory.

This is generally not a fatal error.


@Select layer
\M{Select a single layer}
\T{Select a single layer:}

At this time, you must select a new layer to be used by the next 
higher level function.

The current layer is identified by shading.


@Select layers
\M{Select multiple layers}
\T{Select multiple layers:}

At this time, you must select a new set of layers to be used by 
the next higher level function.

The layers that are currently selected are identified by 
shading.  Selecting a layer that is already active will 
de-select that layer.


@cursor positioning
@Absolute cursor positioning
\M{Absolute cursor positioning}
\T{Absolute cursor positioning:}

Independent of the mouse, the arrow keys, and the grid snap 
settings, the cursor can be moved to any position relative to 
either the current cursor or the local zero point.

To access this feature, you simply type the new XY position 
using the number keys along the top of the main keyboard (not 
the numeric keypad).  A prompting message will be displayed 
upon entry of the first digit.  A signed number will reference 
the current cursor location while an unsigned number will 
reference the current zero point.  A simple arithmetic processor 
is included to ease the entry process.

Examples:
\L{ +10 -5 &&Relative X \& Y}
\L{ 2500 +0 &&Absolute X, relative Y}
\L{ 0-500 250 &Absolute X \& Y}


@Select import filter
\M{Select an import filter}
\T{Import filter selection:}

In addition to its own native file formats, \S{CIRCAD} can also 
import data files produced by several other popular CAD programs.

If you select a specific translation filter, only that format 
will be considered when processing the input file.  For normal 
operation, automatic import filter selection is most desirable.


@Select import filter
@import filters
\M{Automatic file import filtering}
\T{Automatic file import filtering:}

In addition to its own native file formats, \S{CIRCAD} can also 
automatically import data files produced by several competitive 
CAD packages.  Since the filtering is transparent, all you need 
to do is select the desired file using the \S{Open File} 
function.  The file will be analyzed for content and the 
appropriate translation filter will be utilized.

At the present time, the following import filters are 
available:

\L{ 1.  Protel Autotrax (PCB)}
\L{ 2.  Tango II (PCB)}
\L{ 3.  Tango II (Schematic)}
\L{ 4.  Orcad V2 (PCB)}
\L{ 5.  Orcad SDT (Schematic)}
\L{ 6.  Autodesk/Autocad (\S{DXF})}
\L{ 7.  Gerber (\S{RS-274-D})}
\L{ 8.  HPGL (pen plot)}
\L{ 9.  DMPL (pen plot)}
\L{10.  \S{ASCII}}


@pixel import filters
\M{Automatic file import filtering}
\T{Automatic file import filtering:}

In addition to its own native pixel image file format, \S{CIRCAD} 
can also automatically import pixel image data files produced by 
several popular picture processing packages.  Since the filtering 
is transparent, all you need to do is select the desired file 
using the \S{Open File} function.  The file will be analyzed for 
content and the appropriate translation filter will be utilized.

At the present time, the following import filters are 
available:

\L{ 1.  Microsoft Windows (\S{BMP})}
\L{ 2.  PC Paintbrush (\S{PCX})}


@export filters
\M{File export filtering}
\T{File export filtering:}

In addition to its own native file formats, \S{CIRCAD} can also 
export data files to be compatible with several competitive CAD 
packages.  Since the filtering is transparent, all you need 
to do is select the desired export filter using the 
\S{Save As ...} function.  The file will be automatically 
translated as it is written out to disk.

At the present time, the following export filters are 
available:

\L{ 1.  Protel Autotrax (PCB)}
\L{ 2.  Tango II (PCB)}
\L{ 3.  Orcad V2 (PCB)}
\L{ 4.  Autodesk/Autocad (\S{DXF})}
\L{ 5.  Gerber (\S{RS-274-D})}
\L{ 6.  \S{ASCII}}


@File
@File menu
@File functions
\M{File functions}
The \T{File functions} are used to control the flow of data into 
or out of the active system memory.

The file menu can be invoked by typing \B{<F>} on the keyboard 
and will display the following functions:
\L{  1:  \S{New File}}
\L{  2:  \S{Open File}}
\L{  3:  \S{Close File}}
\L{  4:  \S{Erase File}}
\L{  5:  \S{Next File}}
\L{  6:  \S{Previous File}}
\L{  7:  \S{Save File}}
\L{  8:  \S{Save As ...}}
\L{  9:  \S{File Information}}
\L{ 10:  \S{Gerber Out}}
\L{ 11:  \S{Plotter Out}}
\L{ 12:  \S{BOM Output}}
\L{ 13:  \S{Library View}}
\L{ 14:  \S{Library File}}
\L{ 15:  \S{Exit/Quit}}


@template files
@New File
@File New File
\M{New File}
The \T{New File} function is used to begin a new drawing file 
that does not currently exist on disk.

When you select this function, a pop-up dialog box will appear 
for the entry of a name for the new file.

After entering the new file name, an additional dialog box will 
then appear for the selection of a template file that will be 
used to establish the basic working parameters for the new data 
file.

Related functions and topics:
\L{ 1:  \S{Open File}}
\L{ 2:  \S{Close File}}
\L{ 3:  \S{file naming conventions}}
\L{ 4:  \S{reserved file names}}


@New file name
\M{New file name}
\T{New file name:}

At this time, you must enter the desired new file name or press 
<Escape> to exit from the function.

If the newly entered file name already exists on disk, a warning 
message will appear and you will be prompted to indicate whether 
you want to overwrite the previous data file, enter a new file 
name, or escape from the requested function.

An additional dialog box will then appear which will prompt you 
to enter the name of a template file that will be used to 
establish the basic working parameters for the new data file.


@Select template
\M{Template file selection}
\T{Template file selection:}

At this time, you must select the desired template file type.

A template file is used to establish the basic working 
parameters (i.e layers, colors, draw modes, etc.) for the new 
data file.  The standard template files reside in the 
subdirectory \S{CIRCAD.TPL} and may be customized as required.

If desired, any working file may be used as a template if you 
simply delete the unwanted data.


@Template file name
\M{Template file name}
\T{Template file name:}

At this time, you must enter the name of the desired template 
file.

A template file is used to establish the basic working parameters 
(i.e layers, colors, draw modes, etc.) for the new data file.

If desired, any data file may be used as a template if you 
simply delete the unwanted data.


@New file warning
\M{New file warning}
\C{New file warning:}

If you do not want to over-write the existing file with this 
name, you must enter a different file name, path, or drive.

If you want to open this file for viewing or editing you must 
use the \S{Open File} function.


@Open
@Open File
@File Open File
\M{Open File}
The \T{Open File} function is used to view or edit a data file 
that already exists on disk.  You may open as many files as 
memory space allows.

When you select this function, a pop-up dialog box will appear 
which will allow you to select the desired data file from a 
sorted directory list.  The selected file will be automatically 
passed through a series of \S{import filters} to translate it 
into a usable format.

Opening a file that is currently active in the system is not 
allowed and will result in an error message.  If you wish to edit 
or view a file that has already been opened, you can use either 
the \S{Next File} or \S{Previous File} functions to search for 
the desired file amongst the set of open data files.


@Select data file
\M{Select data file}
\T{Select data file:}

The top line of the menu displays the current drive and directory 
path.  If you modify this entry, be sure to conform to the 
existing format \B{drive:\\path\\}, including the ending backslash.

The second line displays the file search mask (i.e.~*.*).  If 
you enter a name with no wild-card characters, it will be 
treated as a complete file name and the file selection menu will 
be closed.

Within the selection box, directories are listed first and are 
enclosed in brackets.  The special directory entry \B{[..]} is 
used to back down the directory tree.


@Close File
@File Close File
\M{Close File}
The \T{Close File} function is used to remove a data file from 
the active system memory, thus freeing its space for use by 
other files.

If the file has been modified since the most recent save 
operation, a warning message will appear and you will be 
prompted to indicate whether you want to save the current file 
to disk, discard the changes, or escape from the requested 
function.

Related functions:
\L{ 1:  \S{Open File}}
\L{ 2:  \S{Save File}}
\L{ 3:  \S{Erase File}}


@Close save warning
\M{Close save warning}
\C{Close save warning:}

This is a `\T{Save before closing}' warning message.

Selecting \B{[Yes]} will close the current data file and discard 
all changes to the file since the last "Save" operation.


@Erase File
@File Erase File
\M{Erase File}
The \T{Erase File} function is used to remove the current data 
file from disk, thus freeing its disk space for use by other 
files.

Related functions:
\L{ 1:  \S{Save File}}
\L{ 2:  \S{Close File}}


@Erase file warning
\M{Erase file warning}
\C{Erase file warning:}

If you do not want to delete this file from disk, you must 
escape from the erasure function.

Selecting \B{[Yes]} will result in the removal of the current 
data file both on disk and in system memory.


@Next File
@File Next File
\M{Next File}
The \T{Next File} function is used to switch the display and 
editing system to the next sequential element in the set of 
active data files.

The files are accessed in a rotary fashion in the order in which 
they were opened.

This function is available by simply typing \B{<Alt N>}.

Related functions:
\L{ 1:  \S{Open File}}
\L{ 2:  \S{Previous File}}


@Previous File
@File Prev File
\M{Previous File}
The \T{Previous File} function is used to switch the display and 
editing system to the previous sequential element in the set of 
active data files.

The files are accessed in a rotary fashion in the reverse of the 
order in which they were opened.

This function is available by simply typing \B{<Alt hyphen>}.

Related functions:
\L{ 1:  \S{Open File}}
\L{ 2:  \S{Next File}}


@Backup directory
@Backup file
@File backup
@Save File
@File Save
@File Save File
\M{Save File}
The \T{Save File} function is used to write the current data 
file out to disk.  You may use this function periodically during 
an editing session to help protect your work from loss due to 
power outages, etc.

The first time a file is saved (per session), a backup copy is 
created. Additional saves do not disturb this backup copy of the 
file.  The backup file is named by using one of the two 
following methods:

1.~~If a directory exists on the target drive with the name 
\B{d:\\CIRCAD\\BACKUP}, the original file is moved to that 
directory without changing the file name or extension.

2.~~If no such backup directory can be found, then the file name 
extension on disk of the original file is changed to \B{.BAK}.

This function is available by simply typing \B{<Alt W>}.

Related functions:
\L{ 1:  \S{Save As ...}}
\L{ 2:  \S{Close File}}


@Save As ...
@File Save As ...
\M{Save As ...}
The \T{Save As ...} function is used to write the current data 
file out to disk under a different name or in a different file 
format.

When you select this function, a pop-up dialog box will appear 
which will prompt you to enter the new disk file name. The 
current file name is shown in the entry box.  Below the file 
name will be a list of \S{export filters} that are available 
for output data translation.

If the newly entered file name already exists on disk, a warning 
message will appear and you will be prompted to indicate whether 
you want to overwrite the previous data file, enter a new file 
name, or escape from the requested function.

Related functions:
\L{\S{Save File}}
\L{\S{Close File}}


@Save as ...
\M{Save as ...}
This is a \T{Save As ...} file name entry box.  It is used to 
write the current data file out to disk under a different name 
or in a different data format.

If the newly entered file name already exists on disk, a warning 
message will appear and you will be prompted to indicate whether 
you want to overwrite the previous data file, enter a new file 
name, or escape from the requested function.


@File Information
\M{File Information}
The \T{File Information} function is used to display statistical 
information on the current data file.

When you select this function, the current data file is scanned 
and the results are displayed in a pop-up dialog box.


@System/File Information
\M{System/File Information}
\T{File Information:}

The currently active file's drive, path, and name are 
displayed at the top of the dialog box.

The actual extents of the data within the file (in inches) 
are displayed on the left.

Statistical data on the file are displayed on the right.

Memory utilization data are displayed on the bottom.


@Photo plotting
@Gerber plotting
@Gerber Out
@File Gerber Out
\M{Gerber Out}
The \T{Gerber Out} function is used to create a set of data files 
on disk in \S{RS-274-D} format for subsequent plotting by a Gerber 
photo plotter.

When you select this function, a nested series of pop-up dialog 
boxes will appear for the specification of the desired output 
data files.

Detailed messages are available [through the hypertext manual] for 
each such dialog box.

An aperture list (wheel) is automatically created by the program 
before the Gerber output files are written.  If you wish to 
supply a pre-defined aperture list, it may be loaded by using 
the \S{Script File} function.

The relative zero point in effect at the time of output will be 
used for the Gerber output data files.


@Gerber plot parameters
@Gerber photo plot
\M{Gerber photo plot parameters}
\T{Gerber photo plot parameters:}

This function is used create a set of output files in \S{RS-274-D} 
format for subsequent plotting by a Gerber photo plotter.  The 
following data are required by this function:

\B{File Name}:~~The three byte entry in this column will be used 
as a suffix to the current file name when writing the Gerber 
files to disk.

\B{File Type}:~~The entry in this column will be chosen from a 
list provided by a secondary selection menu.

\B{Mirror Image}:~~You must specify \B{YES} for any layer that 
is to be printed on the "bottom" of the board.  This applies to 
the under-side of the inner layers as well as the outer surfaces.

\B{Source Layers}:~~This column is used to specify the data file 
layers that are to serve as the source for each of the Gerber 
output files.  Several source layers may be combined into a 
single output file at this time.  This feature is useful when 
producing silk screening with component outlines on both sides 
of the board.

The relative zero point in effect at the time of output will be 
used for the Gerber output data files.

Selecting \B{[Confirm]} will initiate the output.


@Gerber file types
@Select file type
\M{Select file type}
\T{Gerber file type:}

This function is used to set the file type parameter for an 
individual Gerber Plot output file.  A brief description of each 
file type follows:

\B{Copper}:~~This file type must be specified for all target 
layers that are to consist of conductive circuit traces and 
pads. All data contained on layer zero will automatically be 
included with the selected source layer when creating this 
output file.

\B{Plane}:~~This file type must be specified for power and 
ground plane layers.  All data contained on layer zero will 
automatically be included with the selected source layer when 
creating this output file.  All through-pads will be plotted 
as a square or circular `annular ring' with an inside diameter 
equal to that of the actual pad.

\B{Mask}:~~This file type must be specified for both the top 
and the bottom solder resist masking layers.  All data contained 
on the layer zero will automatically be included with the 
selected source layer when creating this output file.  All 
through-pads will be enlarged by 5 mils for clearance before 
they are plotted.

\B{Paste}:~~This file type must be specified for both the top 
and the bottom surface mount solder paste stencil layers.  All 
surface pads on the corresponding copper layers will 
automatically be included with the selected source layer when 
creating this output file.  All surface pads will be shrunk by 
5 mils for clearance before they are plotted.

\B{Drill}:~~This file type is used to create a drill tape for 
the Excellon drill machine.  There should be one and only one 
such file in each set of Gerber output files.  No source layer 
should be called out and the file should not be mirrored.  The 
standard file name suffix is \B{.DRL}.

\B{Symbols}:~~This file type should be specified to create a new 
\S{CIRCAD} data file containing drill drawing symbols instead of 
through-pads.  The resulting file may be read in and plotted or 
converted to a Gerber file in a separate operation.

\B{Silk}:~~This file type must be specified for each target silk 
screen layer.  All data contained on layer zero will 
automatically be included with the selected source layer when 
creating this output file.  No pads are generated for silk 
screen files.

\B{Reports}:~~This file type should be specified once and only 
once per set of Gerber output files.  Doing so will create an 
\S{ASCII} text file containing the Gerber aperture list, the 
Excellon tool list, and the DOS file list.  The resulting file 
may be printed with any listing utility program.


@Pen Plot
@Pen plotting
@Printer plotting
@Plotter Out
@File Plotter Out
\M{Plotter Out}
The \T{Plotter Out} function is used to create a hard copy of the 
current data file on a vector plotter or graphics printer.

When you select this function, a nested series of pop-up dialog 
boxes will appear for the selection of the layers to be plotted 
and the conditions under which the plot will occur.

This function is available by simply typing \B{<Alt P>}.


@Plotter output
\M{Plotting parameters}
\T{Plotting parameters:}

This menu is used to define layer to pen/color translation that 
is to be used for this plotting operation.

Each of the source file layers are listed along with a 
selectable pen or color number to be used when plotting the 
layer.  A pen/color number of zero or null will inhibit plotting 
of that layer.

For black and white printers, a density value from one to seven 
is used for grey scale simulation of color.

Below the layer selection area are three setup commands for the 
various plotting parameters.  Detailed messages are available 
[through the hypertext manual] for each of these functions once they 
have been invoked.

Selecting \B{[Confirm]} will initiate the plotting operation as 
a background task.

Editing can continue on any other data file once the plot has 
commenced.


@Plotter setup
\M{Plotter setup}
\T{Set plotting device parameters:}

\S{Output port}:~~This parameter specifies the serial or 
parallel port to be used when transmitting data to the plotting 
device.  Selecting this entry will invoke an additional pop-up 
dialog box for the selection of the desired output port.

\S{Output type}:~~This parameter specifies the target output 
device type and language to be used.  Selecting this entry will 
invoke an additional pop-up dialog box for the selection of the 
desired output device.

\B{Baud Rate, Parity, Data \& Stop Bits}:~~If the data output 
stream is directed to a serial communications port, these 
parameters must be set to match those of the attached plotting 
device. Consult your plotter manual for the proper line settings.

\B{X \& Y Corrections}:~~Consult your plotter manual for the 
proper settings.

The next group of selections are used to define the "language" 
that will be used to control the plotter.  Each selection will 
invoke a pop-up dialog box for the entry of the specific 
command.  Detailed messages are available [through the hypertext manual] 
for each such dialog box.

The bottom item is pen size setup, a pop-up dialog box will 
appear for the specification of the pen sizes.

Selecting \B{[Save and Confirm]} will accept the current 
parameters and write them to disk so that they will be in effect 
for all future editing sessions.

Selecting \B{[Confirm]} will accept the current parameters for 
the remainder of this editing session.


@Output port
\M{Output port selection}
\T{Output port selection:}

At this time you must select the desired data port that is to be 
used in the subsequent printing or plotting operation.

The current parameter is identified by shading.


@Output type
\M{Output device type selection}
\T{Output device type selection:}

At this time you must select the proper device type to be used 
in the subsequent printing or plotting operation.

The current parameter is identified by shading.

Selecting the `****' entry will utilize a generic vector-oriented
plotting driver that has a programmable command language.  The 
various plotting commands may be modified by the {Command Setup} 
selection in the previous menu.


@Command setup
\M{Plotting command selection}
\T{Plotting command selection:}

If you have selected the generic plotting driver (type ****), 
these commands may be used to customized the language for a wide 
variety of vector-oriented plotters.


@Pen down command
\M{Pen Down command}
\T{Pen Down command:}

At this time you must enter the proper control sequence for a 
`Pen Down' command.

The required character string can be found in your plotter manual.


@Pen up command
\M{Pen Up command}
\T{Pen Up command:}

At this time you must enter the proper control sequence for a 
`Pen Up' command.

The required character string can be found in your plotter manual.


@Pen select command
\M{Pen Select command}
\T{Pen Select command:}

At this time you must enter the proper control sequence for a 
`Pen Select' command.

The required character string can be found in your plotter manual.


@Pen velocity command
\M{Pen Velocity command}
\T{Pen Velocity command:}

At this time you must enter the proper control sequence for a 
`Pen Velocity' command.

The required character string can be found in your plotter manual.


@Pen position command
\M{Pen Position command}
\T{Pen Position command:}

At this time you must enter the proper control sequence for a 
Pen Position' command.

The required character string can be found in your plotter manual.


@Pen init command
\M{Pen Initialization command}
\T{Pen Initialization command:}

At this time you must enter the proper control sequence for the
desired `Initialization' command.

The required character string can be found in your plotter manual.


@Pen stop command
\M{Pen Termination command}
\T{Pen Termination command:}

At this time you must enter the proper control sequence for a 
`Termination' command.

The required character string can be found in your plotter manual.


@Pen setup
\M{Set pen parameters}
\T{Set pen parameters:}

\B{Tip diameter}:~~These numbers are used to specify the size 
(in mils) of the tip of each of the pens.  These values are 
needed in order to properly size and fill lines and pads when 
using a pen plotting device.  These parameters are ignored by 
the printer drivers.

\B{Pen Velocity}:~~This parameter sets the speed that the 
plotter will move the pen during draw operations.  Consult your 
plotter manual for recommendations.  This parameter is ignored 
by the printer drivers.


@Output setup
\M{Set plotting output parameters}
\T{Set plotting output parameters:}

This function is used to crop, align, and scale the file data as 
it is sent to the plotter.

\B{Input X\&Y Min\&Max}:~~These four values are used define a 
rectangle which specifies the plotting extents on the source 
data file.  Any element outside of this rectangle will not be 
processed for plotting.

\B{Input X\&Y Minus}:~~These values are used to indicate the 
"zero-point" of the source data with respect to the plotter.

An easy method of finding these points is to place the 
cross-hair cursor over the desired point on the screen and read 
the XY coordinate values from the status line.  Be sure to drop 
the decimal point when converting to mils.

If a containment block is defined before plotting, the block 
extents and reference point will be used as default values for 
the plot extents and zero point.

\B{Multiply by}:~~This number is used to increase or decrease 
the size of the plot.  Values greater than 1.0000 magnify the 
image while values less than 1.0000 de-magnify the image.  Any 
negative value will mirror the output in the X direction.

\B{Output X\&Y Plus}:~~These values are used to re-locate the 
target zero-point on the plotter.  For HP7400 series plotters, 
small positive values can be used to move the drawing away from 
the far corner of the paper.

All of these values are saved with the data file.


@Plotter draw modes
@Mode setup
\M{Set plotter drawing modes}
\T{Set plotter drawing modes:}

This function is used to set the drawing modes for each of the 
data types.

The lower the number the faster the plotting will be, but the 
resulting plot may be less informative.

Use low numbers to test the position and size of the plot on the 
paper.

With sparse fill you can see both sides of a two sided board.


@Pen plot file name
\M{Pen plot file name}
\T{Pen plot file name:}

At this time you must enter the desired 
\B{drive:\\path\\file.nam} for the plotter data on disk.  If you 
are sending the data to a printer over a networking sub-system, 
simply enter \B{LPT1} or \B{LPT2} as required.


@Bill of Material
@BOM Output
@File BOM Output
\M{Bill of Material output}
The \T{Bill Of Material} output function is used to write out a 
bill of materials and parts listing from the current data file 
to disk in the form of a printable file \S{ASCII} data file.

A pop-up dialog box will appear for the entry of the file name.  
Entering \B{LPT1} or \B{LPT2} will send the report to your printer.

If your printer uses HP laser fonts, you may want to specify 
\B{/H} after the file name to direct the data through the HP 
output filter.


@Bill-of-material file name
\M{Bill of Material file name}
\T{Bill of Material file name:}

At this time you must enter the desired 
\B{drive:\\path\\file.nam} for the BOM data on disk.  If you 
wish to send the data directly to a printer, simply enter 
\B{LPT1} or \B{LPT2} as required.

If your printer uses HP laser fonts, you may want to specify 
\B{/H} after the file name to direct the data through the HP 
output filter.


@Library View
@File Library View
\M{Library View}
The \T{Library View} function is used view or edit the current 
image library data file.

If no library file has been opened, a pop-up dialog box will 
appear for the entry of the desired library file name.


@Library File
@File Library File
\M{Library File}
The \T{Library File} function is used open a new symbols library 
data file.

When you select this function, a pop-up dialog box will appear 
for the entry of the desired library file name.


@Library file name
\M{Library file name}
\T{Library file name:}

At this time you must enter the desired 
\B{drive:\\path\\file.nam} for the library file on disk.  The 
file must be in graphics image format.


@Script File
@File Script File
\M{Script File}
The \T{Script File} function is used load and execute a command 
file from disk.

When you select this function, a pop-up dialog box will appear 
for the entry of the desired script file name.

This function is useful to effect large-scale changes in the 
function or operation of \S{CIRCAD} during a editing session.


@Script file name
\M{Script file name}
\T{Script file name:}

This is a `Script file name' entry box.

At this time you must enter the desired 
\B{drive:\\path\\file.nam} for the script data on disk.


@File Manual/Help
\M{Online Hypertext Reference Manual}
The \T{Manual/Help} function will call this hypertext sub-system.  
Detailed information is available on selection menus, dialog 
boxes, and error messages.

Context-sensitive information is available at any time by pressing 
the \S{<center mouse>} button or \S{<F12>} on the keyboard.  Once 
in the hypertext sub-system, you may receive additional information 
on related topics by selecting any of the text strings that are 
displayed in bold face blue type.  Also, you may jump to an 
entirely unrelated subject by selecting one of the function 
buttons at the bottom of this window.

\L{~}
Do you have a three button mouse?

\S{YES, 3 buttons}%
\R{Three button mouse} &&%
\S{NO, only 2 buttons}%
\R{Two button mouse}


@Exit
@Quit
@Exit/Quit
@File Exit/Quit
\M{Exit/Quit}
The \T{Exit/Quit} function is used end an editing session and 
return to the operating system.

If you have modified any of the active data files, a warning 
message will appear for each such file and you will be prompted 
to indicate whether you want to save the file to disk, discard 
the changes, or escape from the requested function.

This function is available by simply typing \B{<Alt X>}.


@Exit save warning
\M{Exit save warning}
\C{Exit save warning:}

This is a `\T{Save before exit}' warning message.

Selecting \B{[Yes]} will save the file to disk and clear the file 
update flags.

Selecting \B{[No]} will discard any changes to the file.

Selecting \B{[Escape]} will return you to the program.


@Exit plot warning
\M{Exit plot warning}
\C{Exit plot warning:}

This is an `\T{Exit while plotting}' warning message.

At the present time, a plotting operation is still active as a 
background task.

Selecting \B{[Yes]} will cause the unconditional termination of 
the plotting operation.


@PLACE
@Place menu
@Place functions
\M{Place functions}
The \T{Place} functions are used to add new elements to the 
current data file.

The place menu can be invoked be typing \B{<P>} on the keyboard 
and will display the following functions:
\L{  1:  \S{Place Line}}
\L{  2:  \S{Place Ortho-line}}
\L{  3:  \S{Place Route-line}}
\L{  4:  \S{Place Vertex}}
\L{  5:  \S{Place Arc/circle}}
\L{  6:  \S{Place Pad}}
\L{  7:  \S{Place Via}}
\L{  8:  \S{Place Text}}
\L{  9:  \S{Place Component}}
\L{ 10:  \S{Place Filled Solid}}
\L{ 11:  \S{Place Signal Port}}
\L{ 12:  \S{Place Bus Port}}
\L{ 13:  \S{Place +/- Port}}
\L{ 14:  \S{Place Signal GND}}
\L{ 15:  \S{Place Earth GND}}
\L{ 16:  \S{Place Named GND}}
\L{ 17:  \S{Place Signal Name}}
\L{ 18:  \S{Place Signal Dot}}
\L{ 19:  \S{Place Signal Wire}}
\L{ 20:  \S{Place Bus Wire}}
\L{ 21:  \S{Place Arrowhead}}

Most of the selections will invoke a pop-up dialog box for the 
entry of detailed specifications on the item to be placed.


@Place
\M{Place functions}
\T{The new item placement functions:}

The functions in this menu are used to add new elements to the 
current data file.  Most of the selections will invoke a pop-up 
dialog box for the entry of detailed specifications on the item 
to be placed.

Each of these functions will reset the current processing mode 
such that they can be repeated simply by pressing <left~mouse> 
or <Enter>.  Once set in this manner, the function will remain 
in effect until it is reset by a different menu selection.


@Place Line
\M{Place Line}
The \T{Place Line} function is used to construct a straight line 
segment between any two points.

When you select this function, a pop-up dialog box will appear 
which will prompt you to enter the destination layer and line 
thickness.

The default line placement parameters are re-loaded each time 
you grab or edit an existing line segment.  This feature aids 
in replication of existing data structures.

Related functions:
\L{ 1:  \S{Place Ortho-line}}
\L{ 2:  \S{Place Vertex}}
\L{ 3:  \S{Grab Line}}
\L{ 4:  \S{Edit Line}}
\L{ 5:  \S{Delete Line}}


@Place Line parameters
\M{Place Line parameters}
\T{Place Line parameters:}

\B{\S{Layer name}}:~~This parameter specifies the target layer 
onto which the line will be placed.

\B{\S{Line thickness}}:~~This parameter specifies the width 
(in mils) of the "pen" that will be used to draw the line.


@Place: Line
\M{Place: Line}
The system is currently in the \T{Place Line} mode.  This 
function will construct a straight line segment between any 
two points.

Each time you press <left~mouse> or <Enter>, a new line 
segment will be started from the position of the current cursor.

Pressing <right~mouse> or <Escape> will terminate the line 
placement function.

Related functions:
\L{ 1:  \S{Place Ortho-line}}
\L{ 2:  \S{Place Vertex}}
\L{ 3:  \S{Grab Line}}
\L{ 4:  \S{Edit Line}}
\L{ 5:  \S{Delete Line}}


@Place Ortho-line
\M{Place Ortho-line}
The \T{Place Ortho-line} function is used to construct a line 
segment that is constrained to follow one of the four cardinal 
directions and their four diagonals.

When you select this function, a pop-up dialog box will appear 
which will prompt you to enter the destination layer and line 
thickness.

The default line placement parameters are re-loaded each time 
you grab or edit an existing line segment.  This feature aids 
in replication of existing data structures.

Related functions:
\L{ 1:  \S{Place Line}}
\L{ 2:  \S{Place Vertex}}
\L{ 3:  \S{Grab Line}}
\L{ 4:  \S{Edit Line}}
\L{ 5:  \S{Delete Line}}


@Place: O-Line
\M{Place: O-Line}
The system is currently in the \T{Place Ortho-line} mode.  This 
function will construct a line segment that is constrained to 
one of the four cardinal directions and their four diagonals.

Each time you press <left~mouse> or <Enter>, a new line 
segment will be started from the position of the current cursor.

Pressing <right~mouse> or <Escape> will terminate the line 
placement function.

Related functions:
\L{ 1:  \S{Place Line}}
\L{ 2:  \S{Place Vertex}}
\L{ 3:  \S{Grab Line}}
\L{ 4:  \S{Edit Line}}
\L{ 5:  \S{Delete Line}}


@Place Route-line
\M{Place Route-line}
The \T{Place Route-line} function is used to construct a set 
of line segments that are constrained to avoid obstacles such 
as pads, vias, and other lines segments.

The working parameters for this function may be modified by 
using the \S{Nets Auto-route} function.

Related functions:
\L{ 1:  \S{Place Line}}
\L{ 2:  \S{Place Vertex}}
\L{ 3:  \S{Grab Line}}
\L{ 4:  \S{Edit Line}}
\L{ 5:  \S{Delete Line}}


@Place: R-Line
\M{Place: R-Line}
The system is currently in the \T{Place Route-line} mode.  This 
function will construct a set of line segments that are constrained 
to avoid obstacles such as pads, vias, and other lines segments.

Each time you press <left~mouse> or <Enter>, a new rat-line 
segment will be started from the position of the current cursor.

Pressing <right~mouse> or <Escape> will terminate the line 
placement function.

Related functions:
\L{ 1:  \S{Place Line}}
\L{ 2:  \S{Place Vertex}}
\L{ 3:  \S{Grab Line}}
\L{ 4:  \S{Edit Line}}
\L{ 5:  \S{Delete Line}}


@Place Vertex
\M{Place Vertex}
The \T{Place Vertex} function is used to add a vertex to the 
interior of an existing line segment.

This function is useful as an alternative to deleting an 
existing line segment and placing new ones when routing around 
an obstacle.

To use this function, the cursor must be located within the body 
of the desired source line segment.

No pop-up dialog boxes are used by this function.

Related functions:
\L{ 1:  \S{Place Line}}
\L{ 2:  \S{Place Ortho-line}}
\L{ 3:  \S{Grab Vertex}}
\L{ 4:  \S{Delete Vertex}}


@Place: Vertex
\M{Place: Vertex}
The system is currently in the \T{Place Vertex} mode.  This 
function will add a vertex to the interior of an existing line 
segment.

Each time you press <left~mouse> or <Enter>, the area 
directly beneath the cursor point is scanned for a line segment, 
with preference given to lines on the current layer.  If one is 
discovered, it will be broken into two line segments and each of 
the new end-points will be attached to the graphics cursor.

Pressing <right~mouse> or <Escape> will mend the broken line 
segment and return it to its original position.

When the newly created vertex has been positioned as desired, it 
can be tacked down onto the drawing field by pressing 
<left~mouse> or <Enter>.

Immediately upon placement, the vertex can be "unplaced" simply 
by pressing <right~mouse> or <Escape>.

This function is useful as an alternative to deleting an 
existing line segment and placing new ones when routing around 
an obstacle.

Related functions:
\L{ 1:  \S{Place Line}}
\L{ 2:  \S{Place Ortho-line}}
\L{ 3:  \S{Grab Vertex}}
\L{ 4:  \S{Delete Vertex}}


@Place Arc
@Place Arc/circle
\M{Place Arc/circle}
The \T{Place Arc/circle} function is used to create a partial or 
complete circle or ellipse.

When you select this function, a pop-up dialog box will appear 
which will prompt you to enter the several parameters needed for 
the construction of the desired arc.

The default arc placement parameters are re-loaded each time you 
edit an existing arc.  This feature aids in replication of 
existing data structures.

Related functions:
\L{ 1:  \S{Grab Arc edge}}
\L{ 2:  \S{Grab Arc origin}}
\L{ 3:  \S{Edit Arc/circle}}
\L{ 4:  \S{Delete Arc/circle}}


@Arc/circle parameters
\M{Arc/circle parameters}
\T{Arc/circle parameters:}

\S{Layer name}:~~This parameter specifies the target layer onto 
which the arc will be placed.

\S{Line thickness}:~~This parameter specifies the width (in 
mils) of the "pen" that will be used to draw the circumference 
line.

\S{Radius}:~~This parameter specifies the distance (in mils) 
from the central point to the center of the circumference line.

\S{Start angle}:~~This parameter specifies the point at which 
the arc will begin.  This value is specified in degrees 
anti-clockwise from "three o'clock".

\S{Sweep angle}:~~This parameter specifies the length (in 
degrees) of the active chord through which the arc is to be 
drawn.  Negative values yield clockwise arcs.

\S{Elliptical eccentricity}:~~This parameter specifies the ratio 
of the minor radius to the major radius.  A value of one yields 
a circular arc.

\S{Axis angle}:~~This parameter specifies the angle (in degrees 
CCW) through which the reference frame should be rotated prior 
to constructing the arc.  For circular arcs, this value is 
simply added to the `Start angle' parameter.


@Place: Arc
\M{Place: Arc}
The system is currently in the \T{Place Arc} mode.  This function 
will construct an arc using previously defined parameters.

Related functions:
\L{ 1:  \S{Grab Arc edge}}
\L{ 2:  \S{Grab Arc origin}}
\L{ 3:  \S{Edit Arc/circle}}
\L{ 4:  \S{Delete Arc/circle}}


@Place Pad
\M{Place Pad}
The \T{Place Pad} function is used to create a pad, a via, or a 
mounting hole.

When you select this function, a pop-up dialog box will appear 
which will prompt you to enter the several parameters needed for 
the construction of the desired pad.

The default pad placement parameters are re-loaded each time you 
edit an existing pad.  This feature aids in replication of 
existing data structures.

Related functions:
\L{ 1:  \S{Place Via}}
\L{ 2:  \S{Grab Pad/via}}
\L{ 3:  \S{Edit Pad/via}}
\L{ 4:  \S{Delete Pad/via}}


@Place Pad parameters
\M{Place pad parameters}
\T{Place pad parameters:}

\S{Pin name}:~~This parameter is used for identifying pads within 
components.  For free pads, vias, and mounting holes, this 
parameter should be null.

\S{Layer name}:~~This parameter specifies the target layer onto 
which surface-pads are to be placed.  For through-pads, this 
parameter is used to designate the power or ground plane layer 
that is to receive a thermally relieved pad.  All other 
through-pads should be placed on layer zero (Pad Master).

\S{Pad type code}:~~This parameter specifies the target pad's 
type, style, and shape.  When you select this parameter, a 
pop-up dialog box will appear which will display the available 
options.

\S{Pad \& Hole sizes}:~~These parameters are available only for 
through-pads.  These values are specified in mils.

\S{X \& Y sizes}:~~These parameters are available only for 
surface pads.  These values are specified in mils.


@Pad/Via Type
@Select Pad/Via Type
\M{Pad/Via Type}
\T{Pad/Via Type:}

Select your choice from the available list of pad types.  The 
current value is identified by shading.

A brief description of the choices are as follows:

\B{T0}:~~This pad type is used for component pins on schematic 
drawing files.

\B{T1}:~~This pad type is used for all normal pins on printed 
circuit boards.

\B{T2}:~~This pad type is used for to denote component pin one 
on printed circuit boards.

\B{T3}:~~This pad type is used for vias on printed circuit boards.

\B{S0}:~~This pad type is reserved for future expansion and 
should not be used.

\B{S1 \& S2}:~~These pad types are used for surface mount 
components on printed circuit boards.

\B{S3}:~~This pad type is used for connection "dots" on schematic 
drawing files.


@Place: Pad
\M{Place: Pad}
The system is currently in the \T{Place Pad} mode.  This function 
will create a pad, a via, or a mounting hole using previously 
defined parameters.

Related functions:
\L{ 1:  \S{Place Via}}
\L{ 2:  \S{Grab Pad/via}}
\L{ 3:  \S{Edit Pad/via}}
\L{ 4:  \S{Delete Pad/via}}


@Place Via
\M{Place Via}
The \T{Place Via} function is used to create a connecting via at 
the junction of two line segments.

The default parameters used to create the via may be modified by 
using the \S{Setup Via} function.

This function will issue a delay and put itself in auto-repeat 
mode if and only if you invoke it by rolling the cursor to the 
top of the screen and selecting it through the menu system.

Using any other invocation method, this function will place a 
via at the position of the current cursor without altering any 
of the system status parameters.

Related functions:
\L{ 1:  \S{Place Pad}}
\L{ 2:  \S{Grab Pad/via}}
\L{ 3:  \S{Edit Pad/via}}
\L{ 4:  \S{Delete Pad/via}}


@Place: Via
\M{Place: Via}
The system is currently in the \T{Place Via} mode.  This function 
will create a via using the previously defined via parameters.

These parameters may be modified by using the \S{Setup Via} 
function.

Related functions:
\L{ 1:  \S{Place Pad}}
\L{ 2:  \S{Grab Pad/via}}
\L{ 3:  \S{Edit Pad/via}}
\L{ 4:  \S{Delete Pad/via}}


@Place Text
\M{Place Text}
The \T{Place Text} function is used to create an \S{ASCII} text 
string for labeling purposes.

When you select this function, a pop-up dialog box will appear 
which will prompt you to enter the destination layer, text size, 
and rotational angle.

The default text placement parameters are re-loaded each time 
you grab or edit an existing text string.  This feature aids in 
replication of existing data structures.

Related functions:
\L{ 1:  \S{Grab Text}}
\L{ 2:  \S{Edit Text data}}
\L{ 3:  \S{Edit Text parameters}}
\L{ 4:  \S{Delete Text}}


@Place: Text
\M{Place: Text}
The system is currently in the \T{Place Text} mode.  This 
function will create an \S{ASCII} text string using previously 
defined parameters.

These parameters can be changed by re-issuing the \S{Place Text} 
command.

The default text placement parameters are re-loaded each time 
you grab or edit an existing text string.  This feature aids in 
replication of existing data structures.

Related functions:
\L{ 1:  \S{Grab Text}}
\L{ 2:  \S{Edit Text data}}
\L{ 3:  \S{Edit Text parameters}}
\L{ 4:  \S{Delete Text}}


@Place Text Parameters
\M{Place Text parameters}
\T{Place Text parameters:}

\S{Layer name}:~~This parameter specifies the target layer onto 
which the text will be placed.

\S{Text size}:~~This parameter specifies the font height (in 
mils) of the target text string.

\S{Rotation angle}:~~This parameter specifies the angle through 
which the text is to be rotated before it is generated.  This 
value is specified in degrees anti-clockwise from the "normal" 
left to right viewing direction.


@Place Component
\M{Place Component}
The \T{Place Component} function is used to fetch a component 
from the symbols library.

Each time you use this function, a pop-up dialog box will appear 
which will prompt you to enter the several parameters needed to 
define the desired component.

If the component pattern name is not known, entering a question 
mark \B{[?]}, or a null line will invoke the image library in 
browse mode.

The default component placement parameters are re-loaded each 
time you edit an existing component.  This feature aids in 
replication of existing data structures.

Related functions:
\L{ 1:  \S{Grab Component}}
\L{ 2:  \S{Edit Component}}
\L{ 3:  \S{Delete Component}}


@Select library
\M{Select library file}
\T{Select library file:}

At this time, you must select one of the displayed source 
library files.


@Source Library Component Selection
\M{Source Library Component Selection}
\T{Source Library Component Selection:}

At this time, you must select one of the displayed components.


@Component placement
@Component placement parameters
\M{Component placement parameters}
\T{Component placement parameters:}

\B{Pattern name}:~~This parameter specifies the name of the 
physical package or outline of the component.

If you enter any prefix followed by a question mark (i.e.~LS64?), 
a pop-up menu will appear with a selector guide of the matching 
components.

Entering a null or blank pattern name will invoke the resident 
image library.

\B{Reference ID}:~~This parameter is used to identify the 
individual component on the circuit board or schematic drawing.  
This value must be unique to each component.

\B{Type/Value}:~~This parameter is used to specify the "type" of 
semi-conductor chips (i.e. 74LS04), or the "value" of resistors 
and capacitors (i.e. 4.7K or 22F).

\B{Modifier}:~~This parameter is used to specify any auxiliary 
information needed to clarify the individual component.  Typical 
modifiers could specify device tolerance, voltage rating, or 
thermal stability.

The default component placement parameters are re-loaded each 
time you edit an existing component.  This feature aids in 
replication of existing data structures.


@Place: Component
\M{Place: Component}
The system is currently in the \T{Place Component} mode.  This 
function is used to add additional components to the existing 
data file.

Each time you press <left~mouse> or <Enter>, a pop-up dialog 
box will appear for the entry of a component pattern name.  The 
value entered will be used to search the selected image and 
source library files.  If no match is found in any of the 
library files, the current data file is searched for a matching 
component pattern or reference ID name.

If the component pattern name is not known, entering a question 
mark \B{[?]}, or a null line will invoke the image library in 
browse mode.

The default component placement parameters are re-loaded each 
time you edit an existing component.  This feature aids in 
replication of existing data structures.

Related functions:
\L{ 1:  \S{Grab Component}}
\L{ 2:  \S{Edit Component}}
\L{ 3:  \S{Delete Component}}


@SDILC
\M{Image Library Selection}
The system is currently in the \T{Image Library Selection} mode.  
At this time, you must select a component by positioning the 
cursor over the desired part and press <left~mouse> or 
<Enter>.

Pressing <right~mouse> or <Escape> will terminate the library 
selection function.


@Place Filled Solid
\M{Place Filled Solid}
The \T{Place Filled Solid} function is used to construct a region 
which will be completely filled with copper.  The region can be 
of any arbitrary shape, and can be placed on any target layer.

When you select this function, you will be instructed to enter a 
sequence of vertex points.  After selecting a minimum of three 
data points, the function will be completed by pressing 
<right~mouse> or <Escape>.

Once placed, filled areas may be moved about by invoking the 
\S{Grab Filled Solid} function.

A filled region may be modified by first grabbing the desired 
region, then krumping it back into its constituent line 
segments.  The lines can then be modified using the standard 
editing functions.  Once the lines have been suitably 
re-arranged, they can be "un-krumped" back into a filled area 
once again.

Related functions:
\L{ 1:  \S{Grab Filled Solid}}
\L{ 2:  \S{Krump Filled Solid}}
\L{ 3:  \S{Delete Filled Solid}}


@Place: Filled Solid
\M{Place: Filled Solid}
The system is currently in the \T{Place Filled Solid} mode.  This 
function will construct a region that is completely filled with 
copper.  The region may be of any arbitrary shape, and may be 
placed on any target layer.

When you select this function, you will be instructed to enter a 
sequence of vertex points.  After selecting a minimum of three 
data points, the function will be completed by pressing 
<right~mouse> or <Escape>.

Once placed, filled areas may be moved about by invoking the 
\S{Grab Filled Solid} function.

A filled region may be modified by first grabbing the desired 
region, then krumping it back into its constituent line 
segments.  The lines can then be moved modified using the 
standard editing functions.  Once the lines have been suitably 
re-arranged, they can be "un-krumped" back into a filled area 
once again.

Related functions:
\L{ 1:  \S{Grab Filled Solid}}
\L{ 2:  \S{Krump Filled Solid}}
\L{ 3:  \S{Delete Filled Solid}}


@Place Signal Port
\M{Place Signal Port}
The \T{Place Signal Port} function is used to create and name a 
signal port to be connected to other sheets or other places on 
the same sheet.

The signal port that is created is actually a special case of a 
component.  It can be moved or deleted by using the component 
functions.

This function is operational on schematic data files only.

Related functions:
\L{ 1:  \S{Place Bus Port}}
\L{ 2:  \S{Place Signal Name}}
\L{ 3:  \S{Place Signal Wire}}


@Place: Signal Port
\M{Place: Signal Port}
The system is currently in the \T{Place Signal Port} mode.  This 
function will create a signal port to be connected to a signal 
wire.

The signal port that is created is actually a special case of a 
component.  It can be moved or deleted by using the component 
functions.

This function is operational on schematic data files only.

Related functions:
\L{ 1:  \S{Place Bus Port}}
\L{ 2:  \S{Place Signal Name}}
\L{ 3:  \S{Place Signal Wire}}


@Place Bus Port
\M{Place Bus Port}
The \T{Place Bus Port} function is used to create and name a 
signal port to be connected to a signal bus.

The bus port that is created is actually a special case of a 
component.  It can be moved or deleted by using the component 
functions.

This function is operational on schematic data files only.

Related functions:
\L{ 1:  \S{Place Signal Port}}
\L{ 2:  \S{Place Signal Name}}
\L{ 3:  \S{Place Bus Wire}}


@Place: Bus Port
\M{Place: Bus Port}
The system is currently in the \T{Place Bus Port} mode.  This 
function will create a signal port to be connected to a signal 
bus.

The bus port that is created is actually a special case of a 
component.  It can be moved or deleted by using the component 
functions.

This function is operational on schematic data files only.

Related functions:
\L{ 1:  \S{Place Signal Port}}
\L{ 2:  \S{Place Signal Name}}
\L{ 3:  \S{Place Bus Wire}}


@Place +/- Port
\M{Place +/- Power Port}
The \T{Place +/- Port} function is used to create and name a 
positive or negative power or voltage port.

The power port that is created is actually a special case of a 
component.  It can be moved or deleted by using the component 
functions.

This function is operational on schematic data files only.

Related functions:
\L{ 1:  \S{Place Signal GND}}
\L{ 2:  \S{Place Earth GND}}
\L{ 3:  \S{Place Named GND}}


@Place: +/- Port
\M{Place: +/- Power Port}
The system is currently in the \T{Place +/- Power Port} mode.  This 
function will create a signal port to be connected to a positive 
power supply.

The power port that is created is actually a special case of a 
component.  It can be moved or deleted by using the component 
functions.

This function is operational on schematic data files only.

Related functions:
\L{ 1:  \S{Place Signal GND}}
\L{ 2:  \S{Place Earth GND}}
\L{ 3:  \S{Place Named GND}}


@Place Signal GND
\M{Place Signal GND}
The \T{Place Signal GND} function is used to create a normal 
ground port to be connected to a ground plane or ground bus.
The signal will automatically be given a net name of \B{GND}.

The ground port that is created is actually a special case of a 
component.  It can be moved or deleted by using the component 
functions.

This function is operational on schematic data files only.

Related functions:
\L{ 1:  \S{Place Earth GND}}
\L{ 2:  \S{Place Named GND}}
\L{ 3:  \S{Place +/- Port}}
\L{ 4:  \S{Place Signal Name}}


@Place Earth GND
\M{Place Earth GND}
The \T{Place Earth GND} function is used to create a forked 
symbol to be used as a chassis or earth ground port.  The signal 
will automatically be given a net name of \B{EARTH}.

The ground port that is created is actually a special case of a 
component.  It can be moved or deleted by using the component 
functions.

This function is operational on schematic data files only.

Related functions:
\L{ 1:  \S{Place Signal GND}}
\L{ 2:  \S{Place Named GND}}
\L{ 3:  \S{Place +/- Port}}
\L{ 4:  \S{Place Signal Name}}


@Place Named GND
\M{Place Named GND}
The \T{Place Named GND} function is used to create a triangular 
symbol to be used as a logic or analog ground port.  The port 
may be attached to any desired signal net.

The ground port that is created is actually a special case of a 
component.  It can be moved or deleted by using the component 
functions.

This function is operational on schematic data files only.

Related functions:
\L{ 1:  \S{Place Signal GND}}
\L{ 2:  \S{Place Earth GND}}
\L{ 3:  \S{Place +/- Port}}
\L{ 4:  \S{Place Signal Name}}


@Place: Signal Ground
\M{Place: Signal Ground Port}
The system is currently in the \T{Place Signal Ground} mode.  
This function will create a normal ground port to be connected 
to a ground plane or ground bus with a net name of \B{GND}.

The ground port that is created is actually a special case of a 
component.  It can be moved or deleted by using the component 
functions.

This function is operational on schematic data files only.

Related functions:
\L{ 1:  \S{Place Earth GND}}
\L{ 2:  \S{Place Named GND}}
\L{ 3:  \S{Place +/- Port}}
\L{ 4:  \S{Place Signal Name}}


@Place: Earth Ground
\M{Place: Earth Ground Port}
The system is currently in the \T{Place Earth Ground} mode.  
This function will create a fork shaped ground port to be 
connected to chassis or earth ground with a net name of 
\B{EARTH}.

The ground port that is created is actually a special case of a 
component.  It can be moved or deleted by using the component 
functions.

This function is operational on schematic data files only.

Related functions:
\L{ 1:  \S{Place Signal GND}}
\L{ 2:  \S{Place Named GND}}
\L{ 3:  \S{Place +/- Port}}
\L{ 4:  \S{Place Signal Name}}


@Place: Named Ground
\M{Place: Named Ground Port}
The system is currently in the \T{Place Named Ground} mode.  
This function will create a triangle shaped ground port to be 
connected to a logic or analog ground.  The signal name is 
specified at the time of port placement.

The ground port that is created is actually a special case of a 
component.  It can be moved or deleted by using the component 
functions.

This function is operational on schematic data files only.

Related functions:
\L{ 1:  \S{Place Signal GND}}
\L{ 2:  \S{Place Earth GND}}
\L{ 3:  \S{Place +/- Port}}
\L{ 4:  \S{Place Signal Name}}


@Place Signal Name
\M{Place Signal Name}
The \T{Place Signal Name} function is used to attach a name to a 
signal wire.  The signal name will be transmitted from the 
schematic to the PCB through the netlist file.

Once they have been placed, the signal names can be moved, 
edited, or deleted by using any of the text functions.

This function is operational on schematic data files only.

Related functions:
\L{ 1:  \S{Place Signal Port}}
\L{ 2:  \S{Place Signal Wire}}


@Place: Signal Name
\M{Place: Signal Name}
The system is currently in the \T{Place Signal Name} mode.  This 
function is used to attach a name to a signal wire. The signal 
name will be transmitted from the schematic to the PCB through 
the netlist file.

The signal name that is created is actually a special case of a 
text string.  It can be moved, edited, or deleted by using the 
text functions.

This function is operational on schematic data files only.

Related functions:
\L{ 1:  \S{Place Signal Port}}
\L{ 2:  \S{Place Signal Wire}}


@Place Signal Dot
\M{Place Signal Dot}
The \T{Place Signal Dot} function is used to create a 40-mil 
diameter surface-via on the signals layer of a schematic drawing.

Once they have been placed, the signal dots can be moved, edited, 
or deleted by using any of the pad/via functions.

This function is operational on schematic data files only.

Related functions:
\L{ 1:  \S{Place Signal Wire}}


@Place: Signal Dot
\M{Place: Signal Dot}
The system is currently in the \T{Place Signal Dot} mode.  This 
function will create a 40-mil diameter surface-via on the signals 
layer of a schematic drawing.

Once they have been placed, the signal dots can be moved, edited, 
or deleted by using any of the pad/via functions.

This function is operational on schematic data files only.

Related functions:
\L{ 1:  \S{Place Signal Wire}}


@Place Signal Wire
\M{Place Signal Wire}
The \T{Place Signal Wire} function is used to create a 10-mil 
thick ortho-line on the signals layer of a schematic drawing.

Once they have been placed, the signal wires can be moved, 
edited, or deleted by using any of the line functions.

This function is operational on schematic data files only.

Related functions:
\L{ 1:  \S{Place Signal Port}}
\L{ 2:  \S{Place Bus Port}}
\L{ 3:  \S{Place +/- Port}}
\L{ 4:  \S{Place Signal GND}}
\L{ 5:  \S{Place Signal Name}}
\L{ 6:  \S{Place Signal Dot}}
\L{ 7:  \S{Place Bus Wire}}


@Place: Signal Wire
\M{Place: Signal Wire}
The system is currently in the \T{Place Signal Wire} mode.  This 
function will create a 10-mil thick ortho-line on the signals 
layer of a schematic drawing.

Once they have been placed, the signal wires can be moved, 
edited, or deleted by using any of the line functions.

This function is operational on schematic data files only.

Related functions:
\L{ 1:  \S{Place Signal Port}}
\L{ 2:  \S{Place Bus Port}}
\L{ 3:  \S{Place +/- Port}}
\L{ 4:  \S{Place Signal GND}}
\L{ 5:  \S{Place Signal Name}}
\L{ 6:  \S{Place Signal Dot}}
\L{ 7:  \S{Place Bus Wire}}


@Place Bus Wire
\M{Place Bus Wire}
The \T{Place Bus Wire} function is used to create a 50-mil thick 
ortho-line on the symbols layer of a schematic drawing.

Once they have been placed, the bus wires can be moved, edited, 
or deleted by using any of the line functions.

This function is operational on schematic data files only.

Related functions:
\L{ 1:  \S{Place Bus Port}}
\L{ 2:  \S{Place Signal Wire}}


@Place: Bus Wire
\M{Place: Bus Wire}
The system is currently in the \T{Place Bus Wire} mode.  This 
function will create a 50-mil thick ortho-line on the symbols 
layer of a schematic drawing.

Once they have been placed, the bus wires can be moved, edited, 
or deleted by using any of the line functions.

This function is operational on schematic data files only.

Related functions:
\L{ 1:  \S{Place Bus Port}}
\L{ 2:  \S{Place Signal Wire}}


@Place Arrowhead
\M{Place Arrowhead}
The \T{Place Arrowhead} function is used to construct an 
arrowhead onto the currently assigned drawing layer.

The arrowhead that is created is actually a special case of a 
component.  It can be moved or deleted by using the component 
functions.


@Place: Arrowhead
\M{Place: Arrowhead}
The system is currently in the \T{Place Arrowhead} mode.  This 
function will construct an arrowhead onto the currently 
assigned drawing layer.

The arrowhead that is created is actually a special case of a 
component.  It can be moved or deleted by using the component 
functions.


@Grab menu
@Grab functions
\M{Grab functions}
The \T{Grab functions} are used to move existing elements to new 
locations. When an item is selected, it will be removed from the 
file and a "ghost" of the item will attached to the graphics 
cursor and will travel about the file as the cursor is moved.  
In this "ghost" form, the grabbed file element can be rotated in 
90 increments by typing \B{<R>} and can be mirrored by typing 
\B{<X>} or \B{<Y>}.

While they are grabbed, elements can be returned to their 
original position in the file at any time simply by pressing 
<right~mouse> or <Escape>.

When the element has been repositioned as desired, it can be set 
back down onto the drawing field by pressing <left~mouse> or 
<Enter>.

Immediately upon placement, the items can be "unplaced" simply 
by pressing <right~mouse> or <Escape>.

The grab menu can be invoked be typing \B{<G>} on the keyboard 
and will display the following functions:
\L{  1:  \S{Grab Line}}
\L{  2:  \S{Grab Vertex}}
\L{  3:  \S{Grab Arc edge}}
\L{  4:  \S{Grab Arc origin}}
\L{  5:  \S{Grab Pad/via}}
\L{  6:  \S{Grab Text}}
\L{  7:  \S{Grab Component}}
\L{  8:  \S{Grab Comp Only}}
\L{  9:  \S{Grab Filled Solid}}
\L{ 10:  \S{Grab Item}}
\L{ 11:  \S{Rotate 90}}
\L{ 12:  \S{Rotate n}}
\L{ 13:  \S{Mirror X}}
\L{ 14:  \S{Mirror Y}}
\L{ 15:  \S{Mirror T/B}}
\L{ 16:  \S{Scale XY}}
\L{ 17:  \S{Size XY}}

No pop-up dialog boxes are used by the grab functions.


@Grab
@The grab functions
\M{The grab functions}
\T{The grab functions:}

The functions in this menu are used to move existing elements to 
new locations.  When an item is selected, it will be removed 
from the file and a "ghost" of the item will attached to the 
graphics cursor and will travel about the file as the cursor is 
moved. In this "ghost" form, the grabbed file element can be 
rotated in 90 increments by typing \B{<R>} and can be mirrored 
by typing \B{<X>} or \B{<Y>}.

While they are grabbed, elements can be returned to their 
original position in the file at any time simply by pressing 
<right~mouse> or <Escape>.

When the element has been repositioned as desired, it can be set 
back down onto the drawing field by pressing <left~mouse> or 
<Enter>.

Immediately upon placement, the items can be "unplaced" simply 
by pressing <right~mouse> or <Escape>.

Each of these functions will reset the current processing mode 
such that they can be repeated simply by pressing <left~mouse> 
or <Enter>.  Once set in this manner, the function will remain 
in effect until it is reset by a different menu selection.

No pop-up dialog boxes are used by the grab functions.


@Grab Line
\M{Grab Line}
The \T{Grab Line} function is used to pick up and move the entire 
body of one line segment, along with any free pads, vias, and 
other vertices coincident with the line segment's end-points.

To grab a line segment, you must first position the cursor 
somewhere within the interior of the desired line segment and 
then press <left~mouse> or <Enter>.

In the event of multiple targets, lines on the current layer are 
given preference over those on other layers, and shorter lines 
are given preference over longer ones.

Lines contained within components are accessible only from the
proper layer.

Related functions:
\L{ 1:  \S{Grab Vertex}}
\L{ 2:  \S{Place Line}}
\L{ 3:  \S{Edit Line}}
\L{ 4:  \S{Delete Line}}


@Grab: Line
\M{Grab: Line}
The system is currently in the \T{Grab Line} mode.  This function 
will pick up and move one entire line segment, along with any 
free pads, vias, and other vertices coincident with the line 
segment's end-points.

To grab a line segment, you must first position the cursor 
somewhere within the interior desired line segment and then 
press <left~mouse> or <Enter>.

In the event of multiple targets, lines on the current layer are 
given preference over those on other layers, and shorter lines 
are given preference over longer ones.

Lines contained within components are accessible only from the
proper layer.

Related functions:
\L{ 1:  \S{Grab Vertex}}
\L{ 2:  \S{Place Line}}
\L{ 3:  \S{Edit Line}}
\L{ 4:  \S{Delete Line}}


@Grab Vertex
\M{Grab Vertex}
The \T{Grab Vertex}  function is used to pick up and move all 
coincident line segment end-points and vias at a an interior 
point of a multi-line track.

To grab a vertex, you must first position the cursor on or very 
nearly on the desired vertex and then press <left~mouse> or 
<Enter>.  The cursor will jump to the precise vertex point.

When working in a densely populated area, it is useful to 
pre-select the desired target layer.

Vertices of lines contained within components are accessible 
only from the proper layer.

Related functions:
\L{ 1:  \S{Grab Line}}
\L{ 2:  \S{Place Vertex}}
\L{ 3:  \S{Delete Vertex}}


@Grab: Vertex
\M{Grab: Vertex}
The system is currently in the \T{Grab Vertex} mode.  This 
function will pick up and move all coincident line segment 
end-points and vias at a an interior point of a multi-line track.

To grab a vertex, you must first position the cursor on or very 
nearly on the desired vertex and then press <left~mouse> or 
<Enter>.  The cursor will jump to the precise vertex point.

When working in a densely populated area, it is useful to 
pre-select the desired target layer.

Vertices of lines contained within components are accessible 
only from the proper layer.

Related functions:
\L{ 1:  \S{Grab Line}}
\L{ 2:  \S{Place Vertex}}
\L{ 3:  \S{Delete Vertex}}


@Grab Arc
@Grab Arc edge
\M{Grab Arc edge}
The \T{Grab Arc edge} function is used to pick up and move a 
single arc, circle, or ellipse.

To grab an arc or a circle, you must first position the cursor 
somewhere along the edge (circumference) of the desired 
arc/circle and then press <left~mouse> or <Enter>.  To grab 
an ellipse, you may have the cursor anywhere within its interior.

In the event of overlapping targets, arcs on the current layer 
are given preference over those on other layers, and 
non-elliptical arcs are given preference over elliptical ones.

Arcs contained within components are accessible only from the
proper layer.

Related functions:
\L{ 1:  \S{Grab Arc origin}}
\L{ 2:  \S{Place Arc/circle}}
\L{ 3:  \S{Edit Arc/circle}}
\L{ 4:  \S{Delete Arc/circle}}


@Grab Arc origin
\M{Grab Arc origin}
The \T{Grab Arc origin} function is used to pick up and move a 
single arc, circle, or ellipse.

To grab an arc or a circle, you must first position the cursor 
somewhere along the edge (circumference) of the desired 
arc/circle and then press <left~mouse> or <Enter>.  To grab 
an ellipse, you may have the cursor anywhere within its interior.

The cursor will jump to the precise center point of the target 
item.

In the event of overlapping targets, arcs on the current layer 
are given preference over those on other layers, and 
non-elliptical arcs are given preference over elliptical ones.

Arcs contained within components are accessible only from the
proper layer.

Related functions:
\L{ 1:  \S{Grab Arc edge}}
\L{ 2:  \S{Place Arc/circle}}
\L{ 3:  \S{Edit Arc/circle}}
\L{ 4:  \S{Delete Arc/circle}}


@Grab: Arc
\M{Grab: Arc}
The system is currently in the \T{Grab Arc} mode.  This function 
will pick up and move a single arc, circle, or ellipse.

To grab an arc or a circle, you must first position the cursor 
somewhere along the edge (circumference) of the desired 
arc/circle and then press <left~mouse> or <Enter>.  To grab 
an ellipse, you may have the cursor anywhere within its interior.

In the event of overlapping targets, arcs on the current layer 
are given preference over those on other layers, and 
non-elliptical arcs are given preference over elliptical ones.

Arcs contained within components are accessible only from the
proper layer.

Related functions:
\L{ 1:  \S{Place Arc/circle}}
\L{ 2:  \S{Edit Arc/circle}}
\L{ 3:  \S{Delete Arc/circle}}


@Grab Pad
@Grab Via
@Grab Pad/via
\M{Grab Pad/via}
The \T{Grab Pad/via} function is used to pick up and move a 
single free pad, via, or mounting hole.

To grab a pad, you must first position the cursor somewhere 
within the interior of the desired pad and then press 
<left~mouse> or <Enter>.  The cursor will jump to the precise 
center point of the target pad.

Related functions:
\L{ 1:  \S{Place Pad}}
\L{ 2:  \S{Place Via}}
\L{ 3:  \S{Edit Pad/via}}
\L{ 4:  \S{Delete Pad/via}}


@Grab: Pad
\M{Grab: Pad}
The system is currently in the \T{Grab Pad} mode.  This function 
will pick up and move a single free pad, via, or mounting hole.

To grab a pad, you must first position the cursor somewhere 
within the interior of the desired pad and then press 
<left~mouse> or <Enter>.  The cursor will jump to the precise 
center point of the target pad.

Related functions:
\L{ 1:  \S{Place Pad}}
\L{ 2:  \S{Place Via}}
\L{ 3:  \S{Edit Pad/via}}
\L{ 4:  \S{Delete Pad/via}}


@Grab Text
\M{Grab Text}
The \T{Grab Text} function is used to pick up and move a single 
text string.

To grab a text string, you must first position the cursor 
somewhere within the interior of the desired text string and 
then press <left~mouse> or <Enter>. The cursor will jump to 
the starting baseline of the target text string.

In the event of overlapping targets, items on the current layer 
or items not owned by a component are given preference.

Related functions:
\L{ 1:  \S{Place Text}}
\L{ 2:  \S{Edit Text data}}
\L{ 3:  \S{Edit Text parameters}}
\L{ 4:  \S{Delete Text}}


@Grab: Text
\M{Grab: Text}
The system is currently in the \T{Grab Text} mode.  This function 
will pick up and move a single text string.

To grab a text string, you must first position the cursor 
somewhere within the interior of the desired text string and 
then press <left~mouse> or <Enter>. The cursor will jump to 
the starting baseline of the target text string.

In the event of overlapping targets, items on the current layer 
or items not owned by a component are given preference.

Related functions:
\L{ 1:  \S{Place Text}}
\L{ 2:  \S{Edit Text data}}
\L{ 3:  \S{Edit Text parameters}}
\L{ 4:  \S{Delete Text}}


@Grab Component
\M{Grab Component}
The \T{Grab Component} function is used to pick up and move a 
component and all line segment vertices coincident with the 
component's signal pads.

To grab a component, you must first position the cursor 
somewhere within the interior of the desired component and then 
press <left~mouse> or <Enter>. The cursor will jump to the 
component reference point.

In the event of overlapping target components, smaller 
components are given preference over larger ones.

Related functions:
\L{ 1:  \S{Place Component}}
\L{ 2:  \S{Edit Component}}
\L{ 3:  \S{Delete Component}}


@Grab: Component
\M{Grab: Component}
The system is currently in the \T{Grab Component} mode.  This 
function will pick up and move a component and all line segment 
vertices coincident with the component's signal pads.

To grab a component, you must first position the cursor 
somewhere within the interior of the desired component and then 
press <left~mouse> or <Enter>. The cursor will jump to the 
component reference point.

In the event of overlapping target components, smaller 
components are given preference over larger ones.

Related functions:
\L{ 1:  \S{Place Component}}
\L{ 2:  \S{Edit Component}}
\L{ 3:  \S{Delete Component}}


@Grab Comp Only
@Grab Component Only
\M{Grab Component Only}
The \T{Grab Component Only} function is used to pick up and move 
a component while leaving the signal tracks behind.

To grab a component, you must first position the cursor 
somewhere within the interior of the desired component and then 
press <left~mouse> or <Enter>. The cursor will jump to the 
component reference point.

In the event of overlapping target components, smaller 
components are given preference over larger ones.

Related functions:
\L{ 1:  \S{Place Component}}
\L{ 2:  \S{Edit Component}}
\L{ 3:  \S{Delete Component}}


@Grab Filled Solid
\M{Grab Filled Solid}
The \T{Grab Filled Solid} function is used to pick up and move a 
solid filled region.

To grab a solid, you must first position the cursor somewhere 
within the interior of the desired region and then press 
<left~mouse> or <Enter>.

In the event of overlapping targets, solids on the on the 
current layer are given preference over those on other layers, 
and smaller areas are given preference over larger ones.

Once grabbed, a filled area may be modified by first krumping it 
into its constituent line segments.  The lines can then be 
modified using the standard editing functions.  Once the lines 
have been suitably re-arranged, they can be "un-krumped" back 
into a solidly filled area once again.

Items contained within components are not accessible with this 
function.

Related functions:
\L{ 1:  \S{Place Filled Solid}}
\L{ 2:  \S{Delete Filled Solid}}
\L{ 3:  \S{Krump Filled Solid}}


@Grab: Filled Solid
\M{Grab: Filled Solid}
The system is currently in the \T{Grab Filled Solid} mode.  This 
function will pick up and move a solid filled area.

To grab a solid area, you must first position the cursor 
somewhere within the interior of the desired region and then 
press <left~mouse> or <Enter>.

In the event of overlapping targets, solids on the on the 
current layer are given preference over those on other layers, 
and smaller areas are given preference over larger ones.

Items contained within components are not accessible with this 
function.

Related functions:
\L{ 1:  \S{Place Filled Solid}}
\L{ 2:  \S{Delete Filled Solid}}
\L{ 3:  \S{Krump Filled Solid}}


@Grab Item
\M{Grab Item}
The \T{Grab Item} function is both powerful and difficult to use.  
The current working layer must be correctly set and the cursor 
positioning must be absolutely accurate before this function can 
be used.  Any of the primitive items can be grabbed and attached 
to the cursor, even if they are contained within a component.

1.~~Pads and arcs must be grabbed from their exact center point.

2.~~Line end-points must be grabbed from their exact end-point.

3.~~Complete lines segments may be grabbed from any point along 
the mathematical center line.


@Grab: Item
\M{Grab: Item}
The system is currently in the \T{Grab Item} mode.  This function 
is both powerful and difficult to use.  The current working 
layer must be correctly set and the cursor positioning must be 
absolutely accurate before this function can be used.

Any of the primitive items can be grabbed and attached to the 
cursor, even if they are contained within a component.

1.~~Pads and arcs must be grabbed from their exact center point.

2.~~Line end-points must be grabbed from their exact end-point.

3.~~Complete lines segments may be grabbed from any point along 
the mathematical center line.


@Rotate 90
@Grab Rotate 90
\M{Rotate 90}
The \T{Rotate 90} function may be used to rotate any grabbed 
cursor attachments.

Each time you invoke this function, all items attached to the 
cursor will be rotated by 90 in an anti-clockwise direction 
using the cursor as the center of rotation.  The items will 
remain in the ghost form until they are released by pressing 
<left~mouse> or <Enter>.

This function is available by simply typing \B{<R>} when a item 
is grabbed.

Related functions:
\L{ 1:  \S{Rotate n}}
\L{ 2:  \S{Rotate Upside-down}}
\L{ 3:  \S{Mirror X}}
\L{ 4:  \S{Mirror Y}}


@rotation
@Rotate n
@Grab Rotate n
\M{Rotate n}
The \T{Rotate n} function may be used to rotate any grabbed 
cursor attachments by any angular amount.

When you select this function, a pop-up dialog box will appear 
for the entry of a rotational value parameter. Once this value 
has been entered, all items attached to the cursor will be 
rotated by in an anti-clockwise direction using the cursor as 
the center of rotation.  The items will remain in the ghost form 
until they are released by pressing <left~mouse> or <Enter>.

To use this function, you must first grab the desired element 
or component.

Related functions:
\L{ 1:  \S{Rotate 90}}
\L{ 2:  \S{Mirror X}}
\L{ 3:  \S{Mirror Y}}


@Rotate Upside-down
\M{Rotate Upside-down}
The \T{Rotate Upside-down} function may be used to rotate any 
grabbed component 180 while leaving the text intact.  This 
operation is useful for resistors, capacitors, and diodes on PCB 
files to align the parts without disturbing the reference 
designators on silk screen layers.

The component will remain in the ghost form until it is released 
by pressing <left~mouse> or <Enter>.

This function is available by simply typing \B{<U>} when a 
component is grabbed.

Related functions:
\L{ 1:  \S{Rotate 90}}
\L{ 2:  \S{Mirror X}}
\L{ 3:  \S{Mirror Y}}


@Mirror X
@Grab Mirror X
\M{Mirror X}
The \T{Mirror X} function may be used to flip any grabbed cursor 
attachments along the X axis for a reversed view.

Each time you invoke this function, all items attached to the 
cursor will be mirrored on the X axis using the cursor as the 
center of translation.  The items will remain in the ghost form 
until they are released by pressing <left~mouse> or <Enter>.

This function is available by simply typing \B{<X>}.

Related functions:
\L{ 1:  \S{Mirror Y}}
\L{ 2:  \S{Mirror T/B}}


@Mirror Y
@Grab Mirror Y
\M{Mirror Y}
The \T{Mirror Y} function may be used to flip any grabbed cursor 
attachments along the Y axis for a reversed view.

Each time you invoke this function, all items attached to the 
cursor will be mirrored on the Y axis using the cursor as the 
center of translation.  The items will remain in the ghost form 
until they are released by pressing <left~mouse> or <Enter>.

This function is available by simply typing \B{<Y>}.

Related functions:
\L{ 1:  \S{Mirror X}}
\L{ 2:  \S{Mirror T/B}}


@Mirror T/B
@Mirror Top/Bottom
@Grab Mirror T/B
\M{Mirror Top/Bottom}
The \T{Mirror T/B} function may be used to mirror any grabbed 
component from the top to the bottom or from the bottom to the 
top.

Each time you invoke this function, the attached component will 
be mirrored along the X axis using the cursor as the center of 
translation. Copper and silk elements within the component will 
be moved to the corresponding layer on the other side of the 
board.

The component will remain in the ghost form until it is released 
by pressing <left~mouse> or <Enter>.

This function is most useful on surface mount components.

Related functions:
\L{ 1:  \S{Mirror X}}
\L{ 2:  \S{Mirror Y}}


@Scale XY
@Grab Scale XY
\M{Scale XY}
The \T{Scale XY} function may be used to magnify or demagnify 
any grabbed cursor attachment by any amount.  Lines, arcs, and 
pads are neither thinned or thickened.

To use this function, you must first grab the desired element or 
component.  When scaling is selected, a pop-up dialog box will 
appear for the entry of the desired magnification factor.  
The re-scaled item will remain in the ghost form until it is 
released by pressing <left~mouse> or <Enter>.

This function is available by simply typing \B{<k>} (lower case) 
when a item is grabbed.

Related functions:
\L{ 1:  \S{Block Scaling}}
\L{ 2:  \S{Size XY}}


@Size XY
@Grab Size XY
\M{Size XY}
The \T{Size XY} function may be used to magnify or demagnify 
any grabbed cursor attachment by any amount.  Lines, arcs, 
and pads (if possible) are proportionately magnified in 
thickness or size.

To use this function, you must first grab the desired element or 
component.  When you sizing is selected, a pop-up dialog box 
will appear for the entry of the desired magnification factor.  
The re-sized item will remain in the ghost form until it is 
released by pressing <left~mouse> or <Enter>.

This function is available by simply typing \B{<K>} (upper case) 
when a item is grabbed.

Related functions:
\L{ 1:  \S{Scale XY}}


@Edit menu
@Edit functions
\M{Edit functions}
The \T{Edit functions} are used to modify the parametric values 
of existing file elements.

The edit menu can be invoked be typing \B{<E>} on the keyboard 
and will display the following functions:
\L{  1:  \S{Edit Line}}
\L{  2:  \S{Edit Arc/circle}}
\L{  3:  \S{Edit Pad/via}}
\L{  4:  \S{Edit Text data}}
\L{  5:  \S{Edit Text parms}}
\L{  6:  \S{Edit Component}}
\L{  7:  \S{Locate Component}}
\L{  8:  \S{Krump Component}}
\L{  9:  \S{Krump Filled Solid}}
\L{ 10:  \S{Snap Item}}

Most of the selections will invoke a pop-up dialog box which 
will list the item's current parameters and will allow the 
modification of those parameters.


@Edit
\M{The editing functions}
\T{The editing functions:}

The functions in this menu are used to modify the parametric 
values of existing file elements.  Most of the selections will 
invoke a pop-up dialog box which will list the item's current 
parameters and will allow the modification of those parameters.

Each of these functions will reset the current processing mode 
such that they can be repeated simply by pressing <left~mouse> 
or <Enter>.  Once set in this manner, the function will remain 
in effect until it is reset by a different menu selection.


@Edit Line
\M{Edit Line}
The \T{Edit Line} function is used to modify line segments by 
changing their thickness or by transferring them to a different 
layer.

To edit a line segment, you must first position the cursor 
somewhere within the interior of the desired line segment and 
then press <left~mouse> or <Enter>.

A pop-up dialog box will appear with the selected line 
parameters and the permissible global editing options.

In the event of multiple targets, lines on the current layer are 
given preference over those on other layers, and shorter lines 
are given preference over longer ones.

Lines contained within components are accessible only from the
proper layer.

Related functions:
\L{ 1:  \S{Place Line}}
\L{ 2:  \S{Grab Line}}
\L{ 3:  \S{Delete Line}}


@Edit Line parameters
\M{Edit Line parameters}
\T{Edit Line parameters:}

\S{Layer name}:~~This parameter specifies the layer onto which 
the line will be reside.

\S{Line thickness}:~~This parameter specifies the width (in 
mils) of the "pen" that will be used to draw the line.


@Edit: Line
\M{Edit: Line}
The system is currently in the \T{Edit Line} mode.  This function 
can modify line segments by changing their thickness or by 
transferring them to a different layer.

To edit a line segment, you must first position the cursor 
somewhere within the interior of the desired line segment and 
then press <left~mouse> or <Enter>.

A pop-up dialog box will appear with the selected line 
parameters and the permissible global editing options.

In the event of multiple targets, lines on the current layer are 
given preference over those on other layers, and shorter lines 
are given preference over longer ones.

Lines contained within components are accessible only from the
proper layer.

Related functions:
\L{ 1:  \S{Place Line}}
\L{ 2:  \S{Grab Line}}
\L{ 3:  \S{Delete Line}}


@Edit Arc
@Edit Arc/circle
\M{Edit Arc/circle}
The \T{Edit Arc/circle} function is used to modify a partial or 
complete circle or ellipse.

To edit an arc, you must first position the cursor somewhere 
within the interior of the desired element and then press 
<left~mouse> or <Enter>.

In the event of overlapping targets, items on the current layer 
are given preference over those on other layers, and items with 
smaller radii are given preference over those with larger radii.

A pop-up dialog box will appear listing the selected arc 
parameters.  No global editing options are available.

Arcs contained within components are accessible only from the
proper layer.

Related functions:
\L{ 1:  \S{Place Arc/circle}}
\L{ 2:  \S{Grab Arc edge}}
\L{ 3:  \S{Grab Arc origin}}
\L{ 4:  \S{Delete Arc/circle}}


@Edit: Arc
\M{Edit: Arc}
The system is currently in the \T{Edit Arc} mode.  This function 
can modify a partial or complete circle or ellipse.

To edit an arc, you must first position the cursor somewhere 
within the interior of the desired element and then press 
<left~mouse> or <Enter>.

A pop-up dialog box will appear listing the selected arc 
parameters.  No global editing options are available.

Arcs contained within components are accessible only from the
proper layer.

Related functions:
\L{ 1:  \S{Place Arc/circle}}
\L{ 2:  \S{Grab Arc edge}}
\L{ 3:  \S{Grab Arc origin}}
\L{ 4:  \S{Delete Arc/circle}}


@Edit Pad
@Edit Pad/via
\M{Edit Pad/via}
The \T{Edit Pad/via} function is used to modify a pad, a via, or 
a mounting hole.

To edit a pad, you must first position the cursor somewhere 
within the interior of the desired element and then press 
<left~mouse> or <Enter>.

A pop-up dialog box will appear with the selected pad parameters 
and the permissible global editing options.

Related functions:
\L{ 1:  \S{Place Pad}}
\L{ 2:  \S{Place Via}}
\L{ 3:  \S{Grab Pad/via}}
\L{ 4:  \S{Delete Pad/via}}


@Edit Pad parameters
\M{Edit Pad parameters}
\T{Edit Pad parameters:}

\S{Signal name}:~~This parameter lists the name of the signal 
"net" of which this pad is a member.

\S{Pin name}:~~This parameter is used for identifying pads 
within components.  For free pads, vias, and mounting holes, 
this parameter should be null.

\S{Layer name}:~~This parameter specifies the target layer onto 
which surface-pads are to be placed.  For through-pads, this 
parameter is used to designate the power or ground plane layer 
that is to receive a thermally relieved pad.  All other 
through-pads should be placed on layer zero (Pad Master).

\S{Pad type code}:~~This parameter specifies the target pad's 
type, style, and shape.  When you select this parameter, a 
pop-up dialog box will appear which will display the available 
options.

\S{Pad \& Hole sizes}:~~These parameters are available only for 
through-pads.  Their values are specified in mils.

\S{X \& Y sizes}:~~These parameters are available only for 
surface pads.  Their values are specified in mils.


@Edit: Pad
\M{Edit: Pad}
The system is currently in the \T{Edit Pad} mode.  This function 
can modify a pad, a via, or a mounting hole.

To edit a pad, you must first position the cursor somewhere 
within the interior of the desired element and then press 
<left~mouse> or <Enter>.

A pop-up dialog box will appear with the selected pad parameters 
and the permissible global editing options.

Related functions:
\L{ 1:  \S{Place Pad}}
\L{ 2:  \S{Place Via}}
\L{ 3:  \S{Grab Pad/via}}
\L{ 4:  \S{Delete Pad/via}}


@Edit Text data
\M{Edit Text data}
The \T{Edit Text data} function is used to modify the \S{ASCII} 
data portion of a text string.

To edit a text string, you must first position the cursor 
somewhere within the interior of the desired text string and 
then press <left~mouse> or <Enter>.

In the event of overlapping targets, items on the current layer 
or items not owned by a component are given preference.

The text will be edited in place on the screen without the aid 
of a pop-up dialog box.

Related functions:
\L{ 1:  \S{Edit Text parameters}}
\L{ 2:  \S{Place Text}}
\L{ 3:  \S{Grab Text}}
\L{ 4:  \S{Delete Text}}


@Edit: Text Data
\M{Edit: Text Data}
The system is currently in the \T{Edit Text data} mode.  This 
function can modify the \S{ASCII} data portion of an text string.

To edit a text string, you must first position the cursor 
somewhere within the interior of the desired text string and 
then press <left~mouse> or <Enter>.

In the event of overlapping targets, items on the current layer 
or items not owned by a component are given preference.

The text is edited in place on the screen without the aid of a 
pop-up dialog box.

Related functions:
\L{ 1:  \S{Edit Text parameters}}
\L{ 2:  \S{Place Text}}
\L{ 3:  \S{Grab Text}}
\L{ 4:  \S{Delete Text}}


@Edit Text parms
@Edit Text parameters
\M{Edit Text parameters}
The \T{Edit Text parameters} function is used to modify the 
parametric portion of a text string.

To edit a text string, you must first position the cursor 
somewhere within the interior of the desired text string and 
then press <left~mouse> or <Enter>.

In the event of overlapping targets, items on the current layer 
or items not owned by a component are given preference.

A pop-up dialog box will appear listing the selected text 
string parameters and the permissible global editing options.

Related functions:
\L{ 1:  \S{Edit Text data}}
\L{ 2:  \S{Place Text}}
\L{ 3:  \S{Grab Text}}
\L{ 4:  \S{Delete Text}}


@Edit: Text Parameters
\M{Edit: Text Parameters}
The system is currently in the \T{Edit Text parameters} mode.  
This function can modify the parametric portion of an \S{ASCII} 
text string.

To edit a text string, you must first position the cursor 
somewhere within the interior of the desired text string and 
then press <left~mouse> or <Enter>.

In the event of overlapping targets, items on the current layer 
or items not owned by a component are given preference.

A pop-up dialog box will appear listing the selected text 
string parameters and the permissible global editing options.

Related functions:
\L{ 1:  \S{Edit Text data}}
\L{ 2:  \S{Place Text}}
\L{ 3:  \S{Grab Text}}
\L{ 4:  \S{Delete Text}}


@Edit Text Parameters
\M{Edit Text parameters}
\T{Edit Text parameters:}

\S{Layer name}:~~This parameter specifies the target layer onto 
which the text will be placed.

\S{Text size}:~~This parameter specifies the font height (in 
mils) of the target text string.

\S{Rotation angle}:~~This parameter specifies the angle through 
which the text is to be rotated before it is generated.  This 
value is specified in degrees anti-clockwise from the "normal" 
left to right viewing direction.


@Edit Component
\M{Edit Component}
The \T{Edit Component} function is used to modify the parameters 
associated with a component.

To edit a component, you must first position the cursor 
somewhere within the interior of the desired component and then 
press <left~mouse> or <Enter>.

In the event of overlapping target components, smaller 
components are given preference over larger ones.

A pop-up dialog box will appear listing the selected component 
parameters.  No global editing options are available.

Related functions:
\L{ 1:  \S{Place Component}}
\L{ 2:  \S{Grab Component}}
\L{ 3:  \S{Delete Component}}


@Component parameters
\M{Component parameters}
\T{Component parameters:}

\S{Pattern name}:~~This parameter specifies the name of the 
physical package or outline of the component.

\S{Reference ID}:~~This parameter is used to identify the 
individual component on the circuit board or schematic drawing.  
This value must be unique to each component.

\S{Type/Value}:~~This parameter is used to specify the "type" of 
semi-conductor chips (i.e. 74LS04), or the "value" of resistors 
and capacitors (i.e. 4.7K or 22F).

\S{Modifier}:~~This parameter is used to specify any auxiliary 
information needed to clarify the individual component.  Typical 
modifiers could specify device tolerance, voltage rating, or 
thermal stability.

The default component placement parameters are re-loaded each 
time you edit an existing component.  This feature aids in 
replication of existing data structures.


@Edit: Component
\M{Edit: Component}
The system is currently in the \T{Edit Component} mode.  
This function can modify the parameters associated with a 
component.

To edit a component, you must first position the cursor 
somewhere within the interior of the desired component and then 
press <left~mouse> or <Enter>.

In the event of overlapping target components, smaller 
components are given preference over larger ones.

A pop-up dialog box will appear listing the selected component 
parameters.  No global editing options are available.

Related functions:
\L{ 1:  \S{Place Component}}
\L{ 2:  \S{Grab Component}}
\L{ 3:  \S{Delete Component}}


@Edit Locate Cmp
@Locate Component
\M{Locate Component}
The \T{Locate Component} function is used to jump the cursor to 
the location of a named component.

Each time you invoke this function, a pop-up dialog box will 
appear prompting you to enter the component search parameters.

If the specified component cannot be located, an apology message 
will be issued.

Related functions:
\L{ 1:  \S{Place Component}}
\L{ 2:  \S{Grab Component}}
\L{ 3:  \S{Delete Component}}


@Component search
\M{Component search}
\T{Component search:}

This is a \B{Component search} name entry box.  Enter the exact 
Reference ID of the desired component.  The current file will be 
scanned for a match and the cursor will jump to the component 
reference point.


@Edit Krump Comp
@Krump Component
\M{Krump Component}
The \T{Krump Component} function is used to modify a component 
by adding items to it, removing items from it, or dissolving the 
component into its constituent parts.

To dissolve a component, you must first "grab" the desired 
component and then enter the key-strokes \B{<EK>}.  A pop-up 
warning message will appear asking for final confirmation 
dissolution function.

To add items to an existing component, you must first "grab" the 
desired item, and then position the cursor somewhere within the 
interior of the desired target component and enter the 
key-strokes \B{<EK>}.  The item may then be moved to its final 
destination position and placed back on the screen.

To remove items from an existing component, you must first 
"grab" the desired item and then position the cursor somewhere 
outside the confines of the original component and enter the 
key-strokes \B{<EK>}.  The item may then be moved to its final 
destination position and placed back on the screen.

Related functions:
\L{ 1:  \S{Place Component}}
\L{ 2:  \S{Grab Component}}
\L{ 3:  \S{Delete Component}}
\L{ 4:  \S{Build Component}}
\L{ 5:  \S{Nest Component}}


@Component dissolution
\M{Component dissolution}
\T{Component dissolution:}

This is a \T{Component dissolution} warning message.

If you proceed by selecting \B{[Yes]}, the grabbed component 
will be dissolved and its constituent parts will be set free.


@Edit Krump Fill
@Krump Filled Solid
\M{Krump Filled Solid}
The \T{Krump Filled Solid} function is used to modify a filled 
solid by adding vertices to it, removing vertices from it, or 
moving one or more of the vertices about.  To dissolve a filled 
solid, you must first "grab" the desired solid and then enter the 
key-strokes \B{<EF>}.  The filled solid will be reduced to a set of 
perimeter lines.  The lines may be modified using any of the 
standard editing functions.

To construct a filled solid, you must first "grab" the one of 
perimeter lines and then enter the key-strokes \B{<EF>}. The file 
will be scanned for a set of lines to define the perimeter of a 
closed region.  The entire group of lines will then be compiled 
into a solidly filled area.


@snap to item
@Snap to Item
@Item Snap
@Snap Item
@Edit Snap Item
\M{Snap Item}
The \T{Snap Item} function is used to jump the cursor to the 
location of a nearby item.

To snap to an item, you must first position the cursor within 
 inch of the desired item.  The cursor will jump to the precise 
insertion point.

In the event of multiple targets the closest matching item will 
be chosen.

When working in a densely populated area, it is useful to 
pre-select the desired target layer.


@Delete menu
@Delete functions
\M{Delete functions}
The \T{Delete functions} are used to remove existing elements 
from a data file.  All of the delete functions can be undone 
immediately simply by pressing <right~mouse> or <Escape>.

The delete menu can be invoked be typing \B{<D>} on the keyboard 
and will display the following functions:
\L{  1:  \S{Delete Line}}
\L{  2:  \S{Delete Multi-line}}
\L{  3:  \S{Delete Vertex}}
\L{  4:  \S{Delete Arc/circle}}
\L{  5:  \S{Delete Pad/via}}
\L{  6:  \S{Delete Text}}
\L{  7:  \S{Delete Component}}
\L{  8:  \S{Delete Filled Solid}}
\L{  9:  \S{Delete Iso-islands}}
\L{ 10:  \S{Delete Grabs}}
\L{ 11:  \S{Delete Hilights}}

No pop-up dialog boxes are used by the delete functions.


@Delete
\M{The deletion functions}
\T{The deletion functions:}

The functions in this menu are used to remove existing elements 
from a data file.  All of the delete functions can be undone 
immediately simply by pressing <right~mouse> or <Escape>.

Each of these functions will reset the current processing mode 
such that they can be repeated simply by pressing <left~mouse> 
or <Enter>.  Once set in this manner, the function will remain 
in effect until it is reset by a different menu selection.

No pop-up dialog boxes are used by the delete functions.


@Delete Line
\M{Delete Line}
The \T{Delete Line} function is used to remove a single line 
segment.

To delete a line segment, you must first position the cursor 
somewhere within the interior of the desired line segment and 
then press <left~mouse> or <Enter>.

In the event of multiple targets, lines on the current layer are 
given preference over those on other layers, and shorter lines 
are given preference over longer ones.

The affected line segment can be "undeleted" immediately simply 
by pressing <right~mouse> or <Escape>.

Lines contained within components are accessible only from the
proper layer.

Related functions:
\L{ 1:  \S{Delete Multi-line}}
\L{ 2:  \S{Delete Vertex}}


@Delete: Line
\M{Delete: Line}
The system is currently in the \T{Delete Line} mode.  This 
function will remove a single line segment.

To delete a line segment, you must first position the cursor 
somewhere within the interior of the desired line segment and 
then press <left~mouse> or <Enter>.

In the event of multiple targets, lines on the current layer are 
given preference over those on other layers, and shorter lines 
are given preference over longer ones.

The affected line segment can be "undeleted" immediately simply 
by pressing <right~mouse> or <Escape>.

Lines contained within components are accessible only from the
proper layer.

Related functions:
\L{ 1:  \S{Delete Multi-line}}
\L{ 2:  \S{Delete Vertex}}


@Delete Track
@Delete Multi-line
\M{Delete Multi-line}
The \T{Delete Multi-line} function is used to remove an entire 
signal track.

To delete a track, you must first position the cursor somewhere 
within the interior of one of the segments of the desired track 
and then press <left~mouse> or <Enter>.

The target line segment is first deleted, then, recursively, 
each line segment, free pad, or via coincident with the deleted 
line segment's end-points.  The process will terminate if a 
component pad encountered.

The affected track can be "undeleted" immediately simply by 
pressing <right~mouse> or <Escape>.

Lines contained within components are accessible only from the
proper layer.

Related functions:
\L{ 1:  \S{Delete Line}}
\L{ 2:  \S{Delete Vertex}}


@Delete: Track
\M{Delete: Track}
The system is currently in the \T{Delete Track} mode.  This 
function will remove an entire signal track.

To delete a track, you must first position the cursor somewhere 
within the interior of one of the segments of the desired track 
and then press <left~mouse> or <Enter>.

The target line segment is first deleted, then, recursively, 
each line segment, free pad, or via coincident with the deleted 
line segment's end-points.  The process will terminate if a 
component pad encountered.

The affected track can be "undeleted" immediately simply by 
pressing <right~mouse> or <Escape>.

Lines contained within components are accessible only from the
proper layer.

Related functions:
\L{ 1:  \S{Delete Line}}
\L{ 2:  \S{Delete Vertex}}


@Delete Vertex
\M{Delete Vertex}
The \T{Delete Vertex} function is used to remove a vertex from 
the interior of an existing multi-line track.

To delete a vertex, you must first position the cursor on or 
very near the desired vertex and then press <left~mouse> or 
<Enter>.

When working in a densely populated area, it is useful to 
pre-select the desired target layer.

The affected vertex can be "undeleted" immediately simply by 
pressing <right~mouse> or <Escape>.

Vertices of lines contained within components are accessible 
only from the proper layer.

Related functions:
\L{ 1:  \S{Delete Line}}
\L{ 2:  \S{Delete Multi-line}}


@Delete: Vertex
\M{Delete: Vertex}
The system is currently in the \T{Delete Vertex} mode.  This 
function will remove a vertex from the interior of an existing 
multi-line track.

To delete a vertex, you must first position the cursor on or 
very near the desired vertex and then press <left~mouse> or 
<Enter>.

When working in a densely populated area, it is useful to 
pre-select the desired target layer.

The affected vertex can be "undeleted" immediately simply by 
pressing <right~mouse> or <Escape>.

Vertices of lines contained within components are accessible 
only from the proper layer.

Related functions:
\L{ 1:  \S{Delete Line}}
\L{ 2:  \S{Delete Multi-line}}


@Delete Arc
@Delete Arc/circle
\M{Delete Arc/circle}
The \T{Delete Arc/circle} function is used to remove an existing 
arc, circle, or ellipse.

To delete an arc, you must first position the cursor somewhere 
within the interior of the desired element and then press 
<left~mouse> or <Enter>.

In the event of overlapping targets, items on the current layer 
are given preference over those on other layers, and items with 
smaller radii are given preference over those with larger radii.

The affected arc can be "undeleted" immediately simply by 
pressing <right~mouse> or <Escape>.

Arcs contained within components are accessible only from the
proper layer.


@Delete: Arc
\M{Delete: Arc}
The system is currently in the \T{Delete Arc} mode.  This 
function will remove an existing arc, circle, or ellipse.

To delete an arc, you must first position the cursor somewhere 
within the interior of the desired element and then press 
<left~mouse> or <Enter>.

In the event of overlapping targets, items on the current layer 
are given preference over those on other layers, and items with 
smaller radii are given preference over those with larger radii.

The affected item can be "undeleted" immediately simply by 
pressing <right~mouse> or <Escape>.

Arcs contained within components are accessible only from the
proper layer.


@Delete Pad
@Delete Via
@Delete Pad/via
\M{Delete Pad/via}
The \T{Delete Pad/via} function is used to remove a free pad, 
a via, or a mounting hole.

To delete an pad, you must first position the cursor somewhere 
within the interior of the desired element and then press 
<left~mouse> or <Enter>.

The affected pad can be "undeleted" immediately simply by 
pressing <right~mouse> or <Escape>.


@Delete: Pad
\M{Delete: Pad}
The system is currently in the \T{Delete Pad} mode.  This 
function will remove a free pad, a via, or a mounting hole.

To delete an pad, you must first position the cursor somewhere 
within the interior of the desired element and then press 
<left~mouse> or <Enter>.

The affected item can be "undeleted" immediately simply by 
pressing <right~mouse> or <Escape>.


@Delete Text
\M{Delete Text}
The \T{Delete Text} function is used to remove an \S{ASCII} text 
string.

In the event of overlapping targets, items on the current layer 
or items not owned by a component are given preference.

The affected text string can be "undeleted" immediately simply 
by pressing <right~mouse> or <Escape>.


@Delete: Text
\M{Delete: Text}
The system is currently in the \T{Delete Text} mode.  This 
function will remove an \S{ASCII} text string.

In the event of overlapping targets, items on the current layer 
or items not owned by a component are given preference.

The affected text string can be "undeleted" immediately simply 
by pressing <right~mouse> or <Escape>.


@Delete Component
\M{Delete Component}
The \T{Delete Component} function is used to remove an entire 
component.  Any attached signal tracks will remain in place.

To delete a component, you must first position the cursor 
somewhere within the interior of the desired component and then 
press <left~mouse> or <Enter>.

In the event of overlapping target components, smaller 
components are given preference over larger ones.

The affected component can be "undeleted" immediately simply 
by pressing <right~mouse> or <Escape>.


@Delete: Component
\M{Delete: Component}
The system is currently in the \T{Delete Component} mode.  This 
function will remove an entire component.  Any attached signal 
tracks will remain in place.

To delete a component, you must first position the cursor 
somewhere within the interior of the desired component and then 
press <left~mouse> or <Enter>.

In the event of overlapping target components, smaller 
components are given preference over larger ones.

The affected component can be "undeleted" immediately simply 
by pressing <right~mouse> or <Escape>.


@Delete Filled Solid
\M{Delete Filled Solid}
The \T{Delete Filled Solid} function is used to remove a solid 
filled region.

To delete a solid, you must first position the cursor somewhere 
within the interior of the desired region and then press 
<left~mouse> or <Enter>.

In the event of overlapping targets, solids on the on the 
current layer are given preference over those on other layers, 
and smaller areas are given preference over larger 
ones.

Items contained within components are not accessible with this 
function.


@Delete: Filled Solid
\M{Delete: Filled Solid}
The system is currently in the \T{Delete Filled Solid} mode.  
This function will pick up and move a solid filled area.

To delete a solid area, you must first position the cursor 
somewhere within the interior of the desired region and then 
press <left~mouse> or <Enter>.

In the event of overlapping targets, solids on the on the 
current layer are given preference over those on other layers, 
and smaller areas are given preference over larger ones.

Items contained within components are not accessible with this 
function.


@Delete Iso-islands
\M{Delete Iso-islands}
The \T{Delete Iso-islands} function is used to delete all 
isolated lines and arcs from copper layers.  An isolated island 
is defined as a section of copper that is not attached to a pad 
or via.

Isolated copper islands are created in large numbers by the 
copper flood functions.


@Delete Grabs
\M{Delete Grabs}
The \T{Delete Grabs} function is used to delete any items that 
have been grabbed and are attached to the mobile graphics cursor.

The affected items can be "undeleted" immediately simply by 
pressing <right~mouse> or <Escape>.


@Hilight, delete
@Delete Hilights
\M{Delete Hilights}
The \T{Delete Hilights} function is used to delete any items that 
have been hilighted.

The affected items cannot be "undeleted".


@Setup
@Setup menu
@Setup functions
\M{Setup functions}
The \T{Setup functions} are used to modify the parametric 
values of the data file.

The setup menu can be invoked be typing \B{<S>} on the keyboard 
and will display the following functions:
\L{  1:  \S{Setup Layers}}
\L{  2:  \S{Setup Draw Modes}}
\L{  3:  \S{Setup Grid Dots}}
\L{  4:  \S{Setup Pixel Image}}
\L{  5:  \S{Setup Zoom Limits}}
\L{  6:  \S{Setup Library Files}}
\L{  7:  \S{Setup Via Parameters}}
\L{  8:  \S{Setup Clearances}}
\L{  9:  \S{Setup Snap Table}}
\L{ 10:  \S{Setup Grid Snap}}
\L{ 11:  \S{Setup Zero Point}}
\L{ 12:  \S{Setup Mirror View}}
\L{ 12:  \S{Setup Ortho Mode}}

Most of the selections will invoke a pop-up dialog box which 
will list the current parameters and will allow the 
modification of those parameters.  Any changes will be saved as 
part of the data file.


@Layer Setup
@Setup Layers
\M{Layer Setup}
The \T{Setup Layers} function is used to control all parameters 
specific to individual layers of the data file.

When you select this function, a nested series of pop-up dialog 
boxes will appear which will display the current layer setup 
parameters and allow you to modify those parameters.


@Layer setup parameters
\M{Setup Layers}
The \T{Setup Layers} function is used to control the various 
parameters specific to individual layers of the data file.

A brief description of the selections follows:

\B{Layer Number}:~~This column shows the internal sequence 
number that is used by the program for processing the layers.  
Initially, these layers are displayed in numerical order.  When 
you select any of the entries in this column, a pop-up menu will 
appear for the re-sequencing of the layers.

\B{Layer Name}:~~This column shows the text string used to 
identify each of the sixteen layers. This name is provided for 
human interface only and is not used by the program.

\B{Layer Type}:~~This column is used to specify the specific 
usage for each of the individual layers.  When you select any of 
the entries in this column, a pop-up menu will appear which will 
provide a list of the available options.

\B{Text Mirror}:~~This column is used to declare the layers as 
being on the "top" side or "bottom" side of the circuit board.  
Selecting any of the entries in this column will cause it to be 
toggled between "YES" and null.

\B{Video Color}:~~This column is used to specify the color each 
layer is to have when its item are drawn on the screen.  When 
you select any of the entries in this column, a pop-up menu will 
appear with a list of available colors.


@Select layer sequence
\M{Select layer sequence}
\T{Set layer stackup:}

The current sequence number of the selected layer is identified 
by shading.

If you select a new layer number, all other layer numbers will 
be shifted accordingly.


@Select layer type
\M{Select layer type}
\T{Select layer type:}

This function is used to set the layer type parameter for an 
individual source layer.

A brief description of each layer type follows:

\B{Silk}:~~This layer type must be specified for each source 
layer that is to consist of painted symbols or pictures of 
components.

\B{Mask}:~~This layer type must be specified for both the top 
and the bottom solder resist masking layers.

\B{Copper}:~~This layer type must be specified for each source 
layer that is to consist of conductive circuit traces and pads.

\B{Plane}:~~This layer type must be specified for each of the 
power and ground plane layers.

\B{Symbols}:~~This layer type should be specified for any layer 
that is to consist of symbols or pictures that are not to be 
placed on the target circuit board.  This includes pictures of 
components on schematic drawing files.

\B{Paste}:~~This layer type must be specified for both the top 
and bottom solder paste stencil layers on surface mount boards.

\B{Schematic}:~~This layer type must be specified for the 
"wiring" layer on schematic drawing files.

\B{Drawing}:~~This layer type should be specified for any layer 
containing data that is not associated with circuit boards or 
schematics.


@Select color
\M{Select layer color}
\T{Select layer color:}

This menu is used to select the color parameter for an individual 
layer as it is displayed on the screen.  The current color value 
is identified by shading.


@Setup Draw Modes
@Screen draw modes
@Screen mode
\M{Setup Draw Modes}
The \T{Setup Draw Modes} function is used to set the drawing 
modes for each of the data types.  The values entered are used 
only by the screen re-draw routines and do not affect any other 
form of output.  The actual data elements within the file are 
not altered.

\B{Line Draw Mode}:~~Controls the generation of lines and arcs 
as they are drawn onto the screen.

\B{Text Draw Mode}:~~Controls the generation of text strings 
as they are drawn onto the screen.

\B{Pad Draw Mode}:~~Controls the generation of pads and vias  
as they are drawn onto the screen.

\B{Pad pin names}:~~Controls the diagnostic display of the pin 
name onto each pad when zoomed in.

\B{Pad signals}:~~Controls the diagnostic display of the signal 
name onto each pad when zoomed in.

\B{Line signals}:~~Controls the diagnostic display of the signal 
name on each line segment when zoomed in.

\B{Angle/distance}:~~Controls the display a set of polar 
coordinates on the status line.

\B{Autopanning}:~~Controls the automatic screen panning feature.


@Zoom Limits Setup
@Setup Zoom Limits
@Zoom limits setup
\M{Setup Zoom Limits}
\T{Set file zoom limits:}

This function is used to contain the ultimate movement of the 
cursor within a restricted region of the total workspace size, 
which extends from -32.768" to +32.767" in both the X and Y 
directions.  It is useful to set zoom limits to suit the size 
of each drawing sheet to help you to keep from getting "lost" 
in the workspace.  The \S{Zoom Limits} command can be used to 
view the entire workspace at a glance.

Four values [X1,Y1 \& X2,Y2] are used to define a rectangle 
which specifies the maximum allowable extents of the current 
data file.  You will not be able to zoom or pan outside of 
these extents.

The numbers are entered in mils (thousandths of an inch) with a 
comma but no spaces between each of the numbers.


@Setup Grid Dots
@Grid dots setup
\M{Setup Grid Dots}
\T{Set grid dot spacing:}

This function is used to set the spatial density of the 
background grid.  Grid dots show up on the screen as hilighted 
pixels on the uniform background color.

The grid dots are provided for human interface only and are not 
used by the program.  Entering a inter-dot spacing value of zero 
will disable the grid dots.


@Pixel image attachment
@Attach an image
\M{Select pixel image function}
The \T{Pixel Image Attachment} menu is used to read, translate, 
and attach a bit-mapped pixel image to the current data file.  
The form and function of this image is similar to what Microsoft 
Windows somewhat jokingly refers to as `wallpaper'.

\S{Alternate image}:~~Swaps the current pixel image with the 
alternate pixel image.  This function is available by simply 
typing \B{<Alt M>}.

\B{Read from scanner}:~~Reads an image from the attached scanning 
device and attaches it to the current data file.

\B{Load from disk}:~~Loads a \S{BMP} or \S{PCX} file from disk 
and attaches it to the current data file.

Once an image has been attached, additional control functions may 
be performed upon it as they are needed.


@Pixel image aquisition
\M{Aquire a pixel image from the scanner}
The \T{Pixel Image Aquisition} menu is used to read a pixel image 
directly from the attached scanning device.

\B{X skip \& Y skip}:~~Specifies the upper left position (in 
inches) of the desired image on the scanner bed.  Scanning will 
begin at this point.

\B{X scan \& Y scan}:~~Specifies the desired image size (in 
inches).

\B{DPI}:~~Specifies the desired scanning resolution in dots per 
linear inch.  Consult your scanner manual for a list of valid 
entries.

\B{Color}:~~Specifies a single color plane to be processed by the 
scanner.  Valid entries are \B{R}ed, \B{G}reen, \B{B}lue, or 
\B{W}hite.

\B{Lightness}:~~Specifies a lightening (positive values) or a 
darkening (negative values) of the scanned image.  Valid entries 
range from +3 (lightest) to -3 (darkest).

Once an image has been attached, additional control functions may 
be performed upon it as they are needed.  For further information, 
see \S{Setup Pixel Image}.


@Setup Pixel Image
\M{Select pixel image function}
The \T{Setup Pixel Image} selection is used to initiate all 
detail functions to be performed upon the background pixel image.  
The form and function of this image is similar to what Microsoft 
Windows somewhat jokingly refers to as `wallpaper'.

\S{Attach an image}:~~Loads a \S{BMP} or \S{PCX} file from disk 
and attaches it to the current data file.  Once an image has 
been loaded, additional control functions may be performed upon 
it as they are needed.

\B{Change resolution}:~~Sets the declared DPI (dots per inch) of 
the attached image to a user supplied value.  This function is 
most useful when the source document (from the scanner) has been 
drawn to a scale other than unity (1:1).

\S{Alternate image}:~~Swaps the current pixel image with the 
alternate pixel image.  This function is available by simply 
typing \B{<Alt M>}.

\B{Move the image}:~~Slides the pixel image left or right as 
well as up or down as specified by the user.  This function is 
used to align a single `source point' on the scanned document 
to an absolute `target point' on the data file.

\S{Gamma control}:~~Invokes an additional menu which displays a 
graph illustrating the current brightness to luminance 
translation table and allows for the modification of that table.

\S{Scale or rotate}:~~Invokes an additional menu with selections 
for mirroring, rotation, and scaling the image.

\B{Release the image}:~~Deletes the pixel image portion of the 
data file while leaving all placed drawing objects intact.  
This function is used after the `reverse engineering' of 
the scanned document is complete and the image itself is no 
longer needed.


@Pixel image rotation
@Scale or rotate
\M{Select axis translation function}
The \T{Pixel Image Rotation} menu allows you to align the current 
pixel image to a desired set of absolute positions or coordinates.

\B{Mirror on X axis}:~~Flips the image from left to right.  This 
function may be used to change the view point from the front to 
the back of the image.

\B{Mirror on Y axis}:~~Flips the image from top to bottom.  This 
function may be used to change the view point from the front to 
the back of the image.

\B{Rotate by 90}:~~Rotates the image by 90 degrees in a counter 
clockwise direction, thus turning the image on its left side.

\B{Rotate by 180}:~~Rotates the image by 180 degrees, thus 
turning the image upside down.

\B{Rotate by 270}:~~Rotates the image by 270 degrees in a 
counter clockwise direction, thus turning the image on its right 
side.

\S{Rotate or Scale}:~~Allows rotation by a small angle as well as 
scaling by a small percentage.

\B{Release the image}:~~Deletes the pixel image portion of the 
data file while leaving all placed drawing objects intact.  
This function is used after the `reverse engineering' of 
the scanned document is complete and the image itself is no 
longer needed.


@Rotate or Scale
\M{Rotate or Scale a pixel image}
The \T{Rotate or Scale} function allows rotation by a small angle 
as well as scaling by a small percentage.  Once invoked, the user 
is prompted to enter three data control points.

The first point identifies the "fixed point" of the subsequent 
rotation and scaling function.  The image at this point will not 
move during translation and thus the selected point should be one 
that has already been aligned with a known absolute position on 
the target data file.

The second point to be entered selects the source point of the 
pixel image.

The third and final point entered selects the target point on the 
data file to which the source point of the pixel image is to be 
moved.  The existing image will be re-constructed with a slight 
rotation or small single axis scaling to align the source pixel 
with the target data point.


@Pixel image control
\M{Select pixel image function}
The \T{Pixel Image Control} menu is used to initiate all 
detail functions to be performed upon the background pixel image.  

\B{Change resolution}:~~Sets the declared DPI (dots per inch) of 
the attached image to a user supplied value.  This function is 
most useful when the source document (from the scanner) has been 
drawn to a scale other than unity (1:1).

\S{Alternate image}:~~Swaps the current pixel image with the 
alternate pixel image.  This function is available by simply 
typing \B{<Alt M>}.

\B{Move the image}:~~Slides the pixel image left or right as 
well as up or down as specified by the user.  This function is 
used to align a single `source point' on the scanned document 
to an absolute `target point' on the data file.

\S{Gamma control}:~~Invokes an additional menu which displays a 
graph illustrating the current brightness to luminance 
translation table and allows for the modification of that table.

\S{Scale or rotate}:~~Invokes an additional menu with selections 
for mirroring, rotation, and scaling the image.

\B{Release the image}:~~Deletes the pixel image portion of the 
data file while leaving all placed drawing objects intact.  
This function is used after the `reverse engineering' of 
the scanned document is complete and the image itself is no 
longer needed.


@Pixel image gamma control
@Gamma control
\M{Select pixel image function}
The \T{Pixel Image Gamma Control} menu displays a graph 
illustrating the current brightness to luminance translation 
table and allows for the modification of that table.

\B{Invert}:~~Creates an inverse translation table from the one 
that is currently in effect.  This is useful for changing a 
negative image back to a positive.

\B{Linear}:~~Creates a unity translation table that provides 
a linear one to one translation from input brightness to output 
luminance.  This is useful on picture files that have already 
been processed by a brightness and contrast enhancement 
algorithm.

\B{Normal}:~~Creates a `normal' translation table that 
balances the brightness and contrast such that each target 
luminance value represents 1/256th of the total number of pixels 
in the image.

\B{Custom}:~~Creates a user defined translation table that 
is linear between specified minimum and maximum values.  Any 
input pixel less than the minimum value will be displayed as 
black, while any input greater than the maximum will be 
displayed as white.  Any input between the min and max values 
will be translated to a linear grey-scale luminance.


@Image release warning
\M{Image release warning}
\C{Image release warning:}

If you do not want to release the pixel image from this file, 
you must escape from the release function.

Selecting \B{[Yes]} will result in the removal of the pixel image 
from the current data file.


@BMP
@BMP pixel image file
\M{BMP file format}
\T{BMP} stands for \B{B}IT \B{M}APPED \B{P}ICTURE.  This data file 
format is widely used by Microsoft Windows as the `wallpaper' 
that decorates the `desktop'.  Any BMP image can attached to a 
CIRCAD data file.  Once attached, the image will zoom and pan 
along with the other placed ojbects.  For further information, 
see \S{Setup Pixel Image}.

The encoding scheme is relatively simple consisting of a file 
header, a color translation table, and a raster pixel image.  
Color images are automatically translated to greyscale by the 
file import module.

\L{\B{BYTES &DESCRIPTION}}
\L{00\~01 &File ID (must be "BM").}
\L{02\~05 &File size in words (ignored).}
\L{06\~09 &Reserved (ignored).}
\L{0A\~0D &Header size (including color palette).}
\L{0E\~11 &Secondary header size (must be 028h).}
\L{12\~15 &Horizontal pixel count (width).}
\L{16\~19 &Vertical pixel count (height).}
\L{1A\~1B &Picture plane count (must be 1).}
\L{1C\~1D &Picture bit count (1, 4, 8, or 24).}
\L{1E\~21 &Compression algorithm (0 or 1).}
\L{22\~25 &Image size in bytes (ignored).}
\L{26\~29 &Horizontal DPM (dots per meter).
\L{2A\~2D &Vertical DPM (dots per meter).
\L{2E\~31 &Colors used count (ignored).
\L{32\~35 &Colors needed count (ignored).
\L{36\~435 &RGBx color palette (processed).
\L{436\~??? &Pixel image data (uncompressed).

CIRCAD's transparent import filtering allows you to read a BMP 
file by simply selecting the desired file when using the 
\S{Open File} function.


@PCX
@PCX pixel image file
\M{PCX file format}
\T{PCX} is an obsolete but still widely accepted format for pixel 
image data files.  It uses an ineffective RLE compression 
algorithm that works well only on `cartoon' images.  With many 
real-life images, the compressed file will actually be larger 
than the raw data file before compression.

Any PCX image can attached to a CIRCAD data file.  Once attached, 
the image will zoom and pan along with the other placed ojbects.  
For further information, see \S{Setup Pixel Image}.

The encoding scheme is relatively simple consisting of a file 
header and a compressed raster pixel image.  The pixel image may 
optionally be followed by a RGB color translation table.  Color 
images are automatically translated to greyscale by the file 
import module.

\L{\B{BYTES &DESCRIPTION}}
\L{00     &File ID (must be 0Ah).}
\L{01     &Version number (must be 05h).}
\L{02     &Compression code (must be 01h).}
\L{03     &Bits per pixel (must be 1 or 8).}
\L{04\~05 &Minimum X pixel (must be 0000h).}
\L{06\~07 &Minimum Y pixel (must be 0000h).}
\L{08\~09 &Maximum X pixel (width-1).}
\L{0A\~0B &Maximum Y pixel (height-1).}
\L{0C\~0D &Horizontal DPI (dots per inch).
\L{0E\~0F &Vertical DPI (dots per inch).
\L{10\~3F &Colormap (ignored).}
\L{40     &Unused (ignored).}
\L{41     &Color plane count (must be 1 or 3).}
\L{42\~43 &Horizontal line width (in bytes).}
\L{44\~45 &Color/BW code (ignored).}
\L{46\~7F &Unused (ignored).}
\L{80\~??? &Pixel image data (compressed).

CIRCAD's transparent import filtering allows you to read a PCX 
file by simply selecting the desired file when using the 
\S{Open File} function.


@Setup Snap Table
@Grid snaps setup
\M{Setup Snap Table}
\T{Set grid snap table:}

This function allows you to either set a temporary grid snap 
setting or an entire new list of grid snap settings.  If you 
enter a single number, that number becomes the new grid snap 
setting.  However, if you enter a set of numbers separated by 
commas, that set will become the new grid snap table.  The 
table can contain up to seven individual grid snap values.

Each time you press \S{<Alt G>} on the keyboard, the system will 
select the next sequential grid snap setting from the table.
The active grid setting is displayed on the status line.

The individual grid snap settings must be entered in mils 
(thousandths of an inch) with a comma but no spaces between 
each of the numbers.


@<Alt G>
@Grid Snap
@Setup Grid Snap
\M{Grid Snap}
The \T{Grid Snap} function is used to switch to the next setting 
from the table of available grid snaps.  The values are accessed 
in a rotary fashion.  The active grid setting is displayed on the 
status line.

The grid snap table can be modified by using the 
\S{Setup Snap Table} function.

This function is available by simply typing \B{<Alt G>}.


@Setup Via
@Setup Via Params
@Setup Via Parameters
@Via parameters
\M{Setup Via Parameters}
\T{Set new via placement parameters:}

This function is used to establish the layer, the pad size, 
and hole size to be used by the \S{Place Via} functions.  When 
invoked, a pop-up dialog box will appear listing the default 
via parameters.

\B{Layer name}:~~This parameter specifies the target layer onto 
which the vias are to be placed.  For through-vias on printed 
circuit boards, this parameter should be set to layer zero (Pad 
Master).  For schematic sheets, it should be set to layer two 
(Signals).

\B{Via size}:~~This parameter specifies the diameter (in mils) 
of the outside of the via.

\B{Hole size}:~~This parameter specifies the diameter (in mils) 
of the drill to be used to create the via.  This number should 
be set to zero for schematic dots.


@Net Clearances
@Setup Clearances
@Clearance zones
\M{Setup clearance parameters}
\T{Set clearance parameters:}

This function is used to define the clearance zones around and 
between lines and pads.

These clearances are used by the various semi-automatic 
functions such as flood fill, cross-hatch, DRC scan, and Gerber 
Output.  The numbers are entered in mils (thousandths of an inch).

\S{Flood Fill}:~~These parameters are used by the flood, hatch, 
and outline functions.  The flood line value defines the 
thickness of the line segments that will be used, which in turn 
will affect how small an opening the flood fill will be able to 
penetrate.  The cross-hatch and outline functions also use this 
same parameter.  The flood to line and flood to pad values defines 
the spacing or clearance to be provided around such objects.

\S{Net Scan}:~~These parameters are used by the net scan 
routines while testing for DRC violations.

\S{Gerber Out}:~~These parameters are used by the Gerber output 
routines when creating its "padstack".  The mask swell value 
defines the magnitude of the oversizing to used on the solder 
mask layers to guarantee non-overlap with the tinned pad area.  
The paste shrink value defined the magnitude of the undersizing 
to be used on the solder paste stencil file to guarantee 
confinement within the tinned pad area.

The plane pad swell value is used on through pads which attach to 
and make connection with a power or ground plane. The Gerber 
output routine creates a special heat-relieved connection to 
prevent heat wicking away from the joint during the soldering 
operation.  This connection is essentially an insulating 
(non-copper) ring around the pad, with four small radial webs to 
make the electrical connection.  This parameter defines how much 
the pad should be enlarged before it is processed.

The plane hole swell value is used on through pads which pass 
through a ground or power plane without making a connection.  The 
Gerber output routine places no pad but instead creates a 
clearance zone around the drill hole from the pad.  This 
parameter defines the magnitude of the swell.


@Library Setup
@Setup Library File
@Setup Library Files
@Library files
\M{Setup Library File}
\T{Setup source library files:}

This function is used to establish a set of source library 
files that are to be used by the \S{Place Component} function.

At this time, you may add, change, or delete any or all of the 
displayed source library files for the current data file.

When placing components, the libraries are searched in sequence 
in the order that is shown.


@Mirror View
@Setup Mirror View
\M{Setup Mirror View}
\T{Mirror image view point:}

This function is used to flip an entire data file along the X 
axis to view it from the opposite side of the board.  This is 
useful as a quick check of various mirrored data structures 
such as bottom side components and text.

This function is available by simply typing \B{<Alt V>}.


@Alternate Pixel Image
@Alternate image
\M{Select Alternate Pixel Image for Viewing}
\T{Swap Pixel images:}

This function is used to swap the current pixel image with the 
alternate pixel image for the current data file.  In the current 
version of the software, up to two pixel images may be attached 
to a single data file.

For further information, see \S{Setup Pixel Image}.

This function is available by simply typing \B{<Alt M>}.


@Set/clear zero point
@Zero Point Setup
@Setup Zero Point
\M{Setup Zero Point}
\T{Set relative zero point:}

This function is used to set or clear the zero reference point 
that is used for the screen coordinate system.  This value is 
also used as the zero point for the Gerber and \S{DXF} export 
filters.

If relative addressing is already in effect, this function will 
restore absolute addressing.

An audible report is produced when relative addressing is 
engaged.

An asterisk will be displayed after XY position on the status 
line while relative addressing is enabled.


@Select zero reference point
\M{Select zero reference point}
\T{Select relative coordinate zero point:}

The system is currently waiting for you to select the zero 
reference point for relative addressing.

At the present time, you must position the cursor in the 
desired location and press <left~mouse> or <Enter>.

Pressing <right~mouse> or <Escape> will terminate this 
function.


@ortho mode
@Toggle Ortho mode
@Setup Ortho Mode
\M{Toggle Ortho mode}
\T{Set/clear ortho-snap mode:}

This function is used to toggle the ortho-snap mode.  Ortho-snap 
mode is observed by the place line and place vertex functions, 
and by all of the grab functions.

An audible report is produced when ortho-snap mode is engaged.

An asterisk will be displayed after the grid-snap on the status 
line while ortho-snap mode is enabled.


@Block menu
@Block functions
\M{Block functions}
The \T{Block} functions are used to temporarily contain a group 
of file elements and to perform transformation functions on all 
elements in the group.

The block menu can be invoked be typing \B{<B>} on the keyboard 
and will display the following functions:
\L{  1:  \S{Block Rectangle}}
\L{  2:  \S{Block Polyline}}
\L{  3:  \S{Block Release}}
\L{  4:  \S{Block Move}}
\L{  5:  \S{Block Copy}}
\L{  6:  \S{Block Delete}}
\L{  7:  \S{Block Rotation}}
\L{  8:  \S{Block Scaling}}
\L{  9:  \S{Block Layers}}
\L{ 10:  \S{Build Component}}
\L{ 11:  \S{Nest Component}}
\L{ 12:  \S{Flood Fill}}
\L{ 13:  \S{Track Iso}}
\L{ 14:  \S{Iso Output}}
\L{ 15:  \S{Mirror X}}
\L{ 16:  \S{Mirror Y}}

Several of the block sub-functions will invoke a pop-up dialog 
box which will list the current parameters and will allow the 
modification of those parameters.


@Block
\M{The block functions}
\T{The block functions:}

The block commands enable you to temporarily contain, or block, 
a regional group of the file elements and to perform 
transformation functions on all elements in the group.

A block is defined by an outline or spatial boundary, and a 
single XY point as a reference.  Once defined, a block can be 
further restricted by selecting a set of source layers to be 
processed.

The block commands act on any complete items within the block, 
such as line segments, endpoints, components, pads, etc. Any 
items that are only partially contained in the block will be 
ignored.


@Block Define
@Block Polyline
\M{Block Polyline}
\T{Block Polyline:}

This command defines the boundaries of an irregularly shaped 
containment block.  Once defined, the block may be further 
restricted by specifying a limited set of source layers.

A polyline block is defined by selecting three or more vertex 
points and a source reference point.

Related functions:
\L{ 1:  \S{Block Rectangle}}
\L{ 2:  \S{Block Release}}
\L{ 3:  \S{Block Layers}}


@Block Rectangle
\M{Block Rectangle}
\T{Block Rectangle:}

This function may be used to define a rectangular containment 
region for the other block functions to act upon.  Once defined, 
the block may be further confined by specifying a restricted set 
of source layers.

A rectangular block is defined by selecting two corner points 
and a source reference point.

Related functions:
\L{ 1:  \S{Block Polyline}}
\L{ 2:  \S{Block Release}}
\L{ 3:  \S{Block Layers}}


@SFCP
\M{First rectangular point}
\T{Define rectangular region:}

The system is currently waiting for you to select the first 
corner point of a rectangular region on the screen.

At the present time, you must position the cursor in the desired 
location and press <left~mouse> or <Enter>.

Pressing <right~mouse> or <Escape> will terminate this 
function.


@SSCP
\M{Second rectangular point}
\T{Define rectangular region:}

The system is currently waiting for you to select the second 
corner point of a rectangular region on the screen.

At the present time, you must position the cursor in the 
desired location and press <left~mouse> or <Enter>.

Pressing <right~mouse> or <Escape> will terminate this 
function.


@SSRP
\M{Select Reference point}
\T{Define reference point:}

The system is currently waiting for you to select the source 
reference point of a containment block on the screen.

At the present time, you must position the cursor in the desired 
location and press <left~mouse> or <Enter>.

Pressing <right~mouse> or <Escape> will terminate this 
function.


@Block Release
\M{Block Release}
\T{Block Release:}

This function may be used to un-define a containment region and 
thus disable block processing.

A containment block must be defined before this function can be 
used.

Related functions:
\L{ 1:  \S{Block Rectangle}}
\L{ 2:  \S{Block Polyline}}


@Block Move
\M{Block Move}
The \T{Block Move} function is used to relocate the data file 
elements within a block containment region to a new position on 
the same data file.

A containment block must be defined in the current file before 
this function can be used.

Related functions:
\L{ 1:  \S{Block Copy}}
\L{ 2:  \S{Block Delete}}
\L{ 3:  \S{Block Layers}}
\L{ 4:  \S{Block Rotation}}
\L{ 5:  \S{Block Scaling}}


@Block: Move
\M{Block: Move}
The system is currently in the \T{Block Move} mode.  This 
function is used to relocate the data file elements within a 
block containment region to a new position on the same data file.

At this time, you must position the cursor at the desired block 
target reference point.  When you press <left~mouse> or 
<Enter>, all data elements within the original block will be 
moved to their new positions.

Pressing <right~mouse> or <Escape> will terminate the block 
movement function.

Related functions:
\L{ 1:  \S{Block Copy}}
\L{ 2:  \S{Block Delete}}
\L{ 3:  \S{Block Layers}}
\L{ 4:  \S{Block Rotation}}
\L{ 5:  \S{Block Scaling}}


@Block Copy
\M{Block Copy}
The \T{Block Copy} function is used to duplicate the data file 
elements within a block containment region to a new position on 
the same data file or in a different data file.

A containment block must be defined before this function can be 
used.

Related functions:
\L{ 1:  \S{Block Move}}
\L{ 2:  \S{Block Delete}}
\L{ 3:  \S{Block Layers}}
\L{ 4:  \S{Block Rotation}}
\L{ 5:  \S{Block Scaling}}


@Block: Copy
\M{Block: Copy}
The system is currently in the \T{Block Copy} mode.  This 
function is used to replicate the data file elements within a 
block containment region to a new position on the same data 
file or in a different data file.

At this time, you must position the cursor at the desired block 
target reference point.  Each time you press <left~mouse> or 
<Enter>, all data elements within the original data block will 
be replicated at their new positions.

Pressing <right~mouse> or <Escape> will terminate the block 
replication function.

Related functions:
\L{ 1:  \S{Block Move}}
\L{ 2:  \S{Block Delete}}
\L{ 3:  \S{Block Layers}}
\L{ 4:  \S{Block Rotation}}
\L{ 5:  \S{Block Scaling}}


@Block Delete
\M{Block Delete}
The \T{Block Delete} function is used to remove all data file 
elements within a block containment region.

A containment block must be defined in the current data file 
before this function can be used.

Related functions:
\L{ 1:  \S{Block Move}}
\L{ 2:  \S{Block Copy}}
\L{ 3:  \S{Block Layers}}


@Flood Fill
@Hatch Fill
@Block Flood Fill
@Block Hatch Fill
@Cross-hatch Fill
@Outline Fill
@Block Outline Fill
\M{Flood, Hatch, and Outline Fill}
The \T{Block Flood Fill} functions are used to outline a set of 
tracks and pads, and then to fill the remainder of the region 
with lines.  This is useful for certain types of ground plane 
areas.

When you select this function, a pop-up dialog box will appear 
which will display the current flood/hatch fill parameters at 
which time you will be able to enter new values.

Line width and spacing may be modified by using the 
\S{Setup Clearances} function.

The current working layer is used as the target fill layer.  
Alternate source layers may be set by using the \S{Block Layers} 
function.

The current grid snap is used as the hatch spacing.

A containment block must be defined in the current data file 
before this function can be used.

Related functions:
\L{ 1:  \S{Delete Iso-islands}}
\L{ 2:  \S{Track Iso}}
\L{ 3:  \S{Iso Output}}


@Flood/crosshatch fill
@Flood/hatch fill parameters
\M{Flood/hatch fill parameters}
\T{Flood/hatch fill parameters}

\B{Source Layers}:~~This parameter specifies the set of layers 
that are to be observed when performing the subsequent fill 
operation.  If no source layers are specified, the target layer 
will be the only one considered.

\B{Target Layer}:~~This parameter specifies the layer onto which 
the flood lines will be placed.  The default value is the 
current active layer.

\B{Flood Line Size}:~~This parameter specifies the width or 
thickness of the flood line to be used, which in turn will 
affect how small an opening the flood fill will be able to 
penetrate.  WARNING: Using too small of a tool size may cause 
a memory overflow due to excessive line count.

\B{Track Clearance}:~~This parameter specifies the amount of 
clear space that is to be reserved around line segments.

\B{Pad Clearance}:~~This parameter specifies the amount of clear 
space that is to be reserved around pads and vias.

\B{Crosshatch Grid}:~~This parameter controls the spacing or 
openness of a crosshatch fill operation.  The default value is 
the current grid snap setting.


@Track Iso
@Block Track Iso
\M{Track Isolation}
The \T{Track Isolation} function is used to construct a 
set of outlines around the tracks and pads on a PCB file, thus 
isolating them from one another, and from the remaining sea of 
copper on the blank board.  Optionally, you may also construct 
a set of flood lines to clear out these areas of unwanted copper.

When you select this function, a pop-up dialog box will appear 
which will display the current isolation parameters at which time 
you will be able to enter new values.

Once isolated and checked for correctness, the PCB data may then 
be converted to mill, drill, and route files by using the 
\S{Iso Output} function.

A containment block must be defined in the current data file 
before this function can be used.


@Circuit Isolation
\M{Isolation parameters}
\T{Isolation parameters}

\B{Source Layers}:~~This parameter specifies the set of layers 
that are to be observed when performing the subsequent isolation 
operation.  If no source layers are specified, the target layer 
will be the only one considered.

\B{Target Layer}:~~This parameter specifies the layer onto which 
the isolation and flood lines will be placed.  The default value 
is the current active layer.

\B{Isolation Pass Count}:~~This parameter specifies the number of 
concentric isolation lines to be produced around each of the 
source items.

\B{Isolation Tool Size}:~~This parameter specifies the diameter 
of the tip of the end mill cutter to be used for the isolation 
passes.

\B{Isolation Overlap Amount}:~~This parameter specifies the 
amount of tool overlap to be used on each successive isolation 
pass.  For clean milling, the overlap should be approximately 
25\% of the tool diameter.

\B{Isolation Item Clearance}:~~This parameter specifies the 
amount of additional clearance to be used around lines and 
pads to compensate for "tool walk" and over-depth cutting.  
Zero mils is acceptable for most applications.

\B{Flood Tool Size}:~~This parameter specifies the diameter 
of the tip of the end mill cutter to be used for the flood 
pass.  A value of zero will inhibit the flood operation.

\B{Flood Overlap Amount}:~~This parameter specifies the amount 
of tool overlap to be used on each successive line in the flood 
operation.  For clean milling, the overlap should be 
approximately 25\% of the tool diameter.

\B{Flood Item Clearance}:~~This parameter specifies the 
amount of additional clearance to be used around lines and 
pads to compensate for "tool walk" and over-depth cutting.  
This value should be at lease as large as the isolation 
clearance to prevent "scallops" along the milled tracks.


@Iso Output
@Block Iso Output
\M{Isolation Output}
The \T{Iso Output} function is used to create a set of files 
to be used to drill, mill, and route a circuit board on a 
prototype board machine.

The file must first be processed by the \S{Track Iso} function
before this function can be used.

When you select this function, a pop-up dialog box will appear 
which will display the current output parameters at which time 
you will be able to enter new values.

A containment block must be defined in the current data file 
before this function can be used.


@Circuit Isolation Output
\M{Isolation Output}
\T{Isolation Output}

\B{File Type}:~~The entries in this column are fixed elements and 
cannot be modified by the user.

\B{File Name}:~~The twelve byte entry in this column will be used 
as file name when writing the CAM files to disk.  A null name will 
inhibit the output of that file type.

\B{Mirror Image}:~~You must specify \B{YES} for any file that is 
to be processed on the "bottom" of the board.  This applies to 
the drill and route files as well as the milling of the outer 
surfaces.

\B{Source Layers}:~~This column is used to specify the data file 
layers that are to serve as the source for each of the CAM 
output files.  Several source layers may be combined into a 
single output file at this time.  Selecting no source layers will 
inhibit the output of that file type.

\B{Path}:~~This parameter specifies the drive and directory for 
the mill, drill, and route files to be created.

Selecting \B{[Confirm]} will initiate the output.


@Block Mirror X
\M{Mirror X}
\T{Mirror in the X dimension:}

This function may be used to flip any contained block items 
along the X axis for a reversed view.

A block move or copy function must be in progress before this 
function can be used.

This function is available by simply typing \B{<X>}.


@Block Mirror Y
\M{Mirror Y}
\T{Mirror in the Y dimension:}

This function may be used to flip any contained block items 
along the Y axis for a reversed view.

A block move or copy function must be in progress before this 
function can be used.

This function is available by simply typing \B{<Y>}.


@Block Rotation
\M{Block Rotation}
The \T{Block Rotation} function is used to control the rotational 
translation parameter to be used by the \S{Block Move} and 
\S{Block Copy} functions.

When you select this function, a pop-up dialog box will appear 
which will display the current rotational parameter at which 
time you will be able to enter a new value.

Arcs and text strings are rotated in increments of /128 
radians, which is equal to 1.40625 degrees.  Pads are rotated in 
90 increments only.

A containment block must be defined before this function can be 
used.


@Block Scaling
\M{Block Scaling}
The \T{Block Scaling} function is used to control the 
magnification translation parameter to be used by the 
\S{Block Move} and \S{Block Copy} functions.  Lines, arcs, and 
pads are neither thinned or thickened.

When you select this function, a pop-up dialog box will appear 
which will display the current magnification factor at which 
time you will be able to enter a new value.

A containment block must be defined before this function can be 
used.


@Block Layers
\M{Block Layers}
The \T{Block Layers} function is used to control the block layer 
inclusion table to be used by the \S{Block Move}, \S{Block Copy}, 
and \S{Block Delete} functions.

When you select this function, a pop-up dialog box will appear 
which will display the layer selections at which time you will 
be able to enter new ones.

A containment block must be defined before this function can be 
used.


@Build Component
@Block Build Comp
@Block Build Component
\M{Build Component}
The \T{Build Component} function is used to consolidate the data 
file elements within a block containment region into a single 
entity known as a "component".  All contained components will 
automatically be dissolved in the process.

A containment block must be defined and must contain at least 
one element before this function can be used.

Related functions:
\L{ 1:  \S{Nest Component}}
\L{ 2:  \S{Krump Component}}


@Nest Component
@Block Nest Comp
@Block Nest Component
\M{Build Nested Component}
The \T{Nest Component} function is used to consolidate all 
components and free data elements within a block containment 
region into a single "super-component".  This nested component 
may then be replicated many times to produce a panel of boards 
for a volume production operation.

A containment block must be defined and must contain at least 
one element before this function can be used.

Related functions:
\L{ 1:  \S{Build Component}}
\L{ 2:  \S{Krump Component}}
\L{ 3:  \S{Insert Component}}


@Scaling factor
\M{Scaling factor}
\T{Scaling factor:}

At this time you must enter a value that is to be used as a 
linear multiplier on the spatial position of grabbed or 
blocked elements.

Note:  Blocked lines, arcs, and pads are not magnified in 
size or thickness.


@Nets menu
@Netlist functions
\M{Netlist functions}
The \T{Netlist functions} are used to process signal "nets" and 
groups of signal nets (net lists).

The netlist menu can be invoked be typing \B{<N>} on the keyboard 
and will display the following functions:
\L{  1:  \S{Netlist In}}
\L{  2:  \S{Netlist Out}}
\L{  3:  \S{Wirelist Out}}
\L{  4:  \S{Nets Rat-nest}}
\L{  5:  \S{Nets Rat-Line}}
\L{  6:  \S{Nets Un-ratnest}}
\L{  7:  \S{Auto-route}}
\L{  8:  \S{Hilite Net}}
\L{  9:  \S{Name Net}}
\L{ 10:  \S{Clear hilite}}
\L{ 11:  \S{Total Hilite}}
\L{ 12:  \S{Net Scan}}
\L{ 13:  \S{Net Scan +}}
\L{ 14:  \S{Net Scan -}}


@Nets
\M{The netlist functions}
\T{The netlist functions:}

The netlist functions are used to process signal "nets" 
and groups of signal nets (net lists).

A detailed message [through the hypertext manual] is available 
for each nets selection.


@Netlist In
@Nets Netlist In
\M{Netlist In}
The \T{Netlist In} function is used to read in a netlist file 
from disk and add its routing information to the current data 
file.  All existing signal names will be lost and will be 
replaced with those on the designated netlist file.  A log file 
will be produced if any errors are encountered in the input 
stream.

When you select this function, a pop-up dialog box will appear 
for the entry of the desired source netlist file name.  For 
multi-sheet schematics, multiple net list files can be processed 
in a single operation.

Related functions:
\L{ 1:  \S{Netlist Out}}
\L{ 2:  \S{Nets Rat-nest}}
\L{ 3:  \S{Nets Rat-line}}
\L{ 4:  \S{Netlist error log}}


@Netlist file name
\M{Netlist file name}
\T{Netlist file name:}

At this time, you must enter the name of the netlist file.  The 
default file name is the same as source file with a \B{.NET} 
suffix.   If the source file name contains a numeric suffix (such 
as \B{.SH1}), that number will be preserved in the output file 
suffix (i.e. \B{.SH1} to \B{.NT1}).  When reading in the 
netlists, selecting "wild-card" characters in the suffix (such as 
\B{.N??}) will process multiple netlist files in a single 
operation.

If the desired netlist file has a different name or resides in a 
different directory, simply erase the current file name and enter 
a new one.


@Netlist Out
@Nets Netlist Out
\M{Netlist Out}
The \T{Netlist Out} function is used to write out the routing 
information from the current data file to disk in the form of a 
netlist.  The file will be scanned for un-named signals and 
sequential numbers will be assigned to those signals.

When you select this function, a pop-up dialog box will appear 
for the entry of the desired destination netlist file name.  The 
default file name is the same as the source file with a \B{.NET} 
suffix.  If the source file name contains a numeric suffix (such 
as \B{.SH1}), that number will be preserved in the output file 
suffix (i.e. \B{.SH1} to \B{.NT1}).

Related functions:
\L{ 1:  \S{Netlist In}}
\L{ 2:  \S{Wirelist Out}}


@Wirelist Out
@Nets Wirelst Out
\M{Wirelist Out}
The \T{Wirelist Out} function is used to write out the routing 
information from the current data file to disk in the form of a 
printable wirelist.

The listing is formatted in signal name order, and shows starting and ending 
part-pin number for each section, centerline track length, and 
via count.  A track stub is noted by a asterisk (\*) in the 
ending pin column.  This stub detection may prove useful on 
high-frequency or capacitance-sensitive signals.

The file must be fully net-listed before this function can be 
used.  If you have created a circuit board manually without the 
aid of a schematic or netlist, you may assign net numbers to all 
un-named nets simply by running the \S{Netlist Out} function.


@Rat-nest
@Nets Rat-nest
\M{Rat-nest}
\T{Rat-nest the file:}

This function is used to generate a set of straight line 
connections needed to complete the routing of a circuit board.

This function is a necessary part of the auto-routing functions.

A rat-nest is also indispensable for routing boards manually, 
giving you a ready guide as to which pins need tracks between 
them.  After you have placed a number of tracks, just rat-nest 
again to get a fresh look at the routing that remains to be done.

Related functions:
\L{ 1:  \S{Nets Rat-line}}
\L{ 2:  \S{Netlist In}}


@Rat-line
@Nets Rat-line
@Nets Rat-Line
\M{Rat-line}
\T{Rat-nest a single net:}

This function is used to generate a set of straight line 
connections for a single signal (net).

This function is useful during manual routing operations.

To use this function, you must place the cursor over one of the 
pads in the desired net.

Related functions:
\L{ 1:  \S{Nets Rat-nest}}
\L{ 2:  \S{Netlist In}}


@Net: Ratline
\M{Net: Ratline}
\T{Rat-nest a single net:}

The system is currently in the \S{Rat-line} mode.  This function 
will create a set of rat-lines for a single signal net.

To use this function, you must place the cursor over one of the 
pads in the desired net.


@Nets Un-ratnest
\M{Un-ratnest}
\T{Un-Ratnest the file:}

This function is used to clear and remove all rat-lines from 
the ratnest layer.

Related functions:
\L{ 1:  \S{Nets Rat-nest}}
\L{ 2:  \S{Nets Rat-line}}


@Auto-route
@Nets Auto-route
\M{Auto-route}
\T{Auto-route the file:}

This function is used to convert a rat-nest of signals into an 
orderly set of signal tracks.

A restricted portion of the board can be routed if you first 
define the desired area using one of the \S{Block Define} 
functions.

When you select this function, a nested series of pop-up dialog 
boxes will appear for the specification of the various 
parameters needed for the routing operation.

Detailed messages [through the hypertext manual] are available for 
each such dialog box.

Related functions:
\L{ 1:  \S{Netlist In}}
\L{ 2:  \S{Nets Rat-nest}}


@Auto-router setup
\M{Auto-router setup}
\T{Setup the Auto-router:}

Each of the source file layers are listed along with a 
selectable routing direction to be used when auto-routing. Any 
combination of layers and routing directions may be used, 
however not all layers are suitable for routing.

Below the layer/direction selection area are two setup commands 
for the various auto-routing parameters. Detailed messages 
[through the hypertext manual] are available for each of these 
functions once they have been invoked.

Selecting \B{[Confirm]} will initiate the auto-routing operation 
as a foreground task.


@Select routing direction
\M{Select routing direction}
\T{Set routing direction:}

This function is used to set the routing direction parameter on 
an individual layer of the data file.

This parameter should be specified only on "copper" layers.


@Select routing algorithms
\M{Auto-routing algorithms}
\T{Algorithm Selection:}

The active selections are indicated by shading.

A brief description of each of the algorithms follows:

\B{Clear all pre-routes}:~~This algorithm should be used as the 
first step of any normal auto-routing function.  If you elect to 
not select this function, you must first manually "rat-nest" the 
board before routing.

\B{In-line routes}:~~This algorithm will construct a short track 
between two adjacent pins that are exactly vertical, horizontal, 
or diagonal of one another with no intervening obstructions.

\B{Memory routes}:~~This algorithm will construct a five segment 
track between corresponding pins on adjacent chips.  This is 
useful for memory planes and data busses on single and double 
sided boards but should not be used on multi-layer boards.

\B{Triple, Double, and Single alley-way routes}:~~These 
algorithms comprise the primary auto-routing functions of 
\S{CIRCAD}.  Only one of the three alley-way algorithms should 
be selected at a time.

\B{Snake-run routes}:~~This algorithm will construct a 
multi-segment track with multiple vias between any two points on 
the board. It uses a "heuristic search" to find the pathway, so 
it is both powerful and slow to run.  It may be useful as a 
final pass to catch a few signals that the alley-way router has 
missed, but it is not intended for and is not usable as the 
primary router for an entire board.


@Item Placement
\M{Auto-routing item sizes}
\T{Setup routing item sizes:}

\B{Track line width}:~~This parameter specifies the width (in 
mils) of the tracks to be constructed while routing.

\B{Via pad \& hole sizes}:~~These parameters specify the size of 
the vias to be constructed while routing.


@Net Hilight
@Hilite Net
@Hilight Net
@Nets Hilite Net
\M{Net Hilight}
The \T{Net Hilight} function is used to illuminate all named pads 
in a signal net.

Once hilighted, the signal net may be re-named.

Related functions:
\L{ 1:  \S{Total Hilight}}
\L{ 2:  \S{Net Scan}}


@Net: Hilight
\M{Net: Hilight}
The system is currently in the \T{Net Hilight} mode.  This 
function will illuminate all named pads in a signal net.

To hilight a group of signal pads, you must first position 
the cursor directly over the desired pad and then press 
<left~mouse> or <Enter>. For surface pads, the proper layer 
must be set prior to selecting the pad.

Once hilighted, a new name may be assigned to the signal net.

Related functions:
\L{ 1:  \S{Total Hilight}}
\L{ 2:  \S{Net Scan}}


@Name Net
@Nets Name Net
\M{Name Net}
\T{Name a signal:}

This function may be used to assign a label to a hilighted 
signal net.

Related functions:
\L{ 1:  \S{Net Hilight}}
\L{ 2:  \S{Netlist In}}
\L{ 3:  \S{Netlist Out}}


@Signal name assignment
\M{Signal name assignment}
\T{Signal name assignment:}

This is a `Signal name assignment' entry box.

At this time, you must enter the desired name for the hilighted 
signal net.  All hilighted items will receive this new name.


@Clear hilite
@Nets Clear hilite
\M{Clear hilite}
\T{Clear all hilighted items:}

This command will clear and any existing highlight condition and 
return the highlighted items to their normal display state.


@Total Hilite
@Total Hilight
@Nets Total hilite
\M{Total Net Hilight}
The \T{Total Hilight} function is used to illuminate all named 
pads and tracks in a signal net globally across all open data 
files.

Related functions:
\L{ 1:  \S{Net Hilight}}
\L{ 2:  \S{Clear hilite}}


@Net: Total hilite
\M{Net: Total Hilight}
The system is currently in the \T{Total hilite} mode.  This 
function will illuminate all named pads and tracks in a signal 
net globally across all open data files.

To hilight a group of signal pads, you must first position 
the cursor directly over the desired pad and then press 
<left~mouse> or <Enter>. For surface pads, the proper layer 
must be set prior to selecting the pad.

Related functions:
\L{ 1:  \S{Net Hilight}}
\L{ 2:  \S{Clear hilite}}


@Net Scan
@Nets Net Scan
@Net: Scan
\M{Net Scan}
The \T{Net Scan} command is used to "sniff out" and illuminate 
all tracks, pads, and vias along a signal pathway.  Once 
hilighted, the signal net may be re-named.

To scan a signal net, you must first position the cursor 
somewhere along the desired signal and then press <left~mouse> 
or <Enter>.

The target line segment is first hilighted, then, recursively, 
each line segment, pad or via that it is in electrical contact 
with.

Related functions:
\L{ 1:  \S{Net Scan +}}
\L{ 2:  \S{Net Scan -}}
\L{ 3:  \S{Net Hilight}}
\L{ 4:  \S{Setup Clearances}}


@Net Scan +
@Nets Net Scan +
\M{Net Scan +}
\T{Scan the Net List forward:}

This function is used to scan a data file for routing errors or 
omissions.

The nets are searched in ascending alphabetical name order.

Related functions:
\L{ 1:  \S{Net Scan}}
\L{ 2:  \S{Net Scan -}}
\L{ 3:  \S{Net Hilight}}
\L{ 4:  \S{Setup Clearances}}


@Net Scan -
@Nets Net Scan -
\M{Net Scan -}
\T{Scan the Net List backward:}

This function is used to scan a data file for routing errors or 
omissions.

The nets are searched in descending alphabetical name order.

Related functions:
\L{ 1:  \S{Net Scan}}
\L{ 2:  \S{Net Scan +}}
\L{ 3:  \S{Net Hilight}}
\L{ 4:  \S{Setup Clearances}}


@Net: Scan +
\M{Net: Scan +}
\T{Scan the Net List forward:}

The system is currently in the \B{Net Scan+} mode.  This function 
will index forward through the signal nets and will "sniff out" 
and illuminate all tracks, pads, and vias along each signal 
pathway.

Related functions:
\L{ 1:  \S{Net Scan}}
\L{ 2:  \S{Net Scan -}}
\L{ 3:  \S{Net Hilight}}
\L{ 4:  \S{Setup Clearances}}


@Net: Scan -
\M{Net: Scan -}
\T{Scan the Net List backward:}

The system is currently in the \B{Net Scan-} mode.  This function 
will index backward through the signal nets and will "sniff out" 
and illuminate all tracks, pads, and vias along each signal 
pathway.

Related functions:
\L{ 1:  \S{Net Scan}}
\L{ 2:  \S{Net Scan +}}
\L{ 3:  \S{Net Hilight}}
\L{ 4:  \S{Setup Clearances}}


@Netlist error log
\M{Netlist error log}
\T{Netlist error log:}

If any errors are encountered while processing the netlists, 
an error log file will be created containing the entire set of 
errors.  This file will have the same path and name as the target 
data file with a suffix of \B{.LOG}.  Listing or printing this 
file will prove useful when "ferreting out" the errors from 
the source schematic file.

The following errors are detected:

\B{Input line invalid}:~~Indicates that \S{CIRCAD} does not 
recognize the format of the input line in the netlist file, and 
cannot process it.

\B{Signal name invalid}:~~The signal name in the netlist 
contains characters that cannot be processed.

\B{Component name invalid}:~~The component name in the netlist 
contains characters that cannot be processed.

\B{Component not found}:~~The component indicated in the netlist 
cannot be found on the board.

\B{Pin not found}:~~A component pin in the netlist cannot be 
found on the board.  This condition may be caused by specifying 
an incorrect pattern for a given component.

\B{Crosslinked pin}:~~A component pin is included in more than 
one signal net.  This condition may be caused by having more 
than one source component with the same reference ID.

\B{Pattern not found}:~~A component pattern in the netlist 
cannot be found in any of the specified library files.

\B{Pattern mismatch}:~~The component pattern in the netlist 
does not match that which is already specified on the board.

\B{Type/value mismatch}:~~The component type/value parameter 
in the netlist does not match that which is already specified 
on the board.

\B{Modifier mismatch}:~~The component modifier parameter in the 
netlist does not match that which is already specified on the 
board.


@Zoom menu
@Zoom functions
\M{Zoom functions}
The \T{Zoom functions} are used to change the view of the current 
data file without affecting the contents of the file.

The zoom menu can be invoked be typing \B{<Z>} on the keyboard 
and will display the following functions:
\L{  1:  \S{Zoom In}}
\L{  2:  \S{Zoom Out}}
\L{  3:  \S{Zoom Unity}}
\L{  4:  \S{Zoom Re-draw}}
\L{  5:  \S{Zoom Layer}}
\L{  6:  \S{Zoom Center}}
\L{  7:  \S{Zoom Limits}}
\L{  8:  \S{Zoom Extents}}
\L{  9:  \S{Zoom Scale}}
\L{ 10:  \S{Zoom Window}}


@Zoom
\M{The zoom functions}
\T{The zoom functions:}

The selections in this menu are used to change the view of the 
current data file without affecting the contents of the file.


@Zoom In
@Zoom In[1.414x]
\M{Zoom In}
The \T{Zoom In} function is used to magnify the image of the data 
file, yielding a smaller field of view at a greater resolution.

Each time this command is called, it magnifies the file view by 
a factor of 1.414, reducing the area viewed by about half, with 
the center of the screen as the reference point.

The ultimate limit of this function is reached when one pixel 
on the screen has a value of .001".


@Zoom Out
@Zoom Out [.707x]
\M{Zoom Out}
The \T{Zoom In} function is used to de-magnify the image of the 
data file, yielding a larger field of view at a lesser resolution.

Each time this command is called, it magnifies the file view by 
a factor of 0.707, increasing the area viewed to about double,
with the center of the screen as the reference point.

The ultimate limit of this function is reached when the file at 
the specified zoom limits just fits on the display screen.


@Zoom Unity
@Zoom Unity[1:1]
\M{Zoom Unity}
The \T{Zoom Unity} function is used to set the zoom scaling to 
unity magnification factor, yielding a view on the screen that 
matches the real world of the final product.

For proper operation of this function, the screen pixel pitch 
must be correctly specified in the initialization file for the 
monitor size and pixel count in effect.


@Zoom Scale
@Zoom Scale [dpi]
\M{Zoom Scale}
The \T{Zoom Scale} function is used to set the zoom scaling to a 
specific magnification factor, specified in dots per inch.

This operation is useful when flooding the screen with a pixel 
image file from a scanner or when dumping the screen to a 
pixel image file for a laser printer.


@Zoom Re-draw
\M{Zoom Re-draw}
\T{Re-draw the display:}

This function is used to re-generate the display screen without 
changing the magnification factor or viewpoint.

If you have been moving or editing overlapping or intersecting 
objects, the display screen tends to acquire a mottled 
appearance.  At any time during such editing, the screen can be 
cleaned up simply and easily by this function.


@Zoom Layer
\M{Zoom Layer}
\T{Select new working layer:}

This function is used to select a new active layer to be used 
for viewing and editing.

When you select this function, a pop-up dialog box will appear 
which will prompt you to select the desired layer. The current 
layer is identified by shading.

When a new layer is selected, that single layer is regenerated 
so as to be prominently displayed on the screen.

The layers can also be selected sequentially by using the \B{<+>} 
and \B{<->} keys on the numeric key pad.


@Zoom Center
\M{Zoom Center}
\T{Re-center the display:}

This function is used to move a desired viewpoint to the center 
of the display screen without changing the magnification factor.


@Zoom Limits
\M{Zoom Limits}
\T{Zoom to file limits:}

This function is used to snap the zoom scaling factor to a 
value such that the entire usable workspace will be visible at 
one time.


@Zoom Extents
\M{Zoom Extents}
\T{Zoom to file extents:}

This function is used to snap the zoom scaling factor to a 
value such that all file elements will be visible at one time 
at the largest magnification possible.


@Zoom Window
\M{Zoom Window}
\T{Zoom to a window:}

This function allows you to define a specific rectangular region 
of the data file and display it at maximum size on the screen.


@Zoom scaling factor
\M{Zoom scaling factor}
\T{Zoom scaling factor:}

This is a `Zoom Scaling Factor' entry box.

This function is used to establish an absolute resolution 
factor for the pixels on the screen as they relate to inches in 
the file.

The value to be entered is specified in dots per linear inch 
[dpi].


@File name display
\M{File name display}
The \T{File name display} function will display the current file 
name on the status line.  The name will remain active on the 
status for a few seconds, after which the status line will be 
returned to its normal display.

This function is only available by typing \B{<Alt F>}.


@Select next shallower layer
\M{Select next shallower layer}
\T{Select next shallower layer:}

This function is may be used to step to the next shallower layer 
in the set of active layers.  This function will fail and sound 
an error alert when layer zero is reached.

This function is only available by typing \B{<->} on the 
numeric keypad.


@Select next deeper layer
\M{Select next deeper layer}
\T{Select next deeper layer:}

This function is may be used to step to the next deeper layer 
in the set of active layers.  This function will fail and sound 
an error alert when layer fifteen is reached.

This function is only available by typing \B{<+>} on the 
numeric keypad.


@keystroke macros
@Keystroke Macro playback
@Keystroke Macro playback
\M{Keystroke Macros}
\T{Keystroke Macros:}

Any short sequence of keystrokes can be recorded in a special 
buffer.  The entire keystroke sequence can then be played back 
again and again with a single keystroke.

To record a keystroke sequence, hold the \B{<Alt>} key and press 
the \B{<*>} key on the numeric keypad.  A short audible "peep" 
will signal the acceptance of the command.  If possible, a 
confirmation message will be displayed on the status line.  All 
following keystrokes will be placed in the macro buffer.  When 
the desired macro keystroke sequence is complete, you must again 
hold the \B{<Alt>} key and press the \B{<*>} key on the numeric 
keypad.

To play back a pre-recorded macro keystroke sequence, simply 
press the \B{<*>} key on the numeric keypad.

Keystroke macros may be saved to disk to be read back at a later 
time by using the \S{Script File} function.


@Snapshot file name
\M{Pixel image file name}
\C{Set pixel image file name:}

This function is used to set a new output file name for the 
screen \S{Snapshot output} function.

This function is still under development and has not yet been 
released for general use.

This function is only available by typing \B{<Alt 8>}.

Related functions:
\L{\S{Snapshot cursor removal}
\L{\S{Snapshot output}


@Snapshot cursor removal
\M{Remove graphics cursor}
\C{Remove graphics cursor:}

This function will clear the graphics cursor so it does not show 
on the screen.  This is useful before taking a pixel image 
snapshot of the screen.

This function is still under development and has not yet been 
released for general use.

This function is only available by typing \B{<Alt 9>}.

Related functions:
\L{\S{Snapshot file name}
\L{\S{Snapshot output}


@Snapshot output
\M{Save screen pixel image}
\C{Save pixel image file:}

This function will record a pixel image snapshot of the graphics 
screen in the form of a \B{.PCL} file.

This function is still under development and has not yet been 
released for general use.

This function is only available by typing \B{<Alt 0>}.

Related functions:
\L{\S{Snapshot file name}
\L{\S{Snapshot cursor removal}


@Insert Component
\M{Insert component}
\C{Insert component:}

This function will insert an exact image of an existing component 
without replicating any of its constituent parts.  This is useful 
when creating a large panel of boards for a production run.  When 
selected, a pop-up dialog box will appear which will prompt you 
to enter the component pattern name to be inserted.  The cursor 
must be properly positioned prior to invocation.

This function is still under development and has not yet been 
released for general use.

This function is only available by typing \B{<Alt F9>}.


@Command line
@Command processor
@Command line processor
\M{Command processor}
\C{Command processor:}

This \B{Command line} function should be used with extreme 
caution, as any data typed in at this time will be fed directly 
into \S{CIRCAD}'s internal command processor.

Incorrect, invalid, or illegal input may cause unpredictable 
results, including system lock-ups.

This function is only available by typing \B{<Alt C>}.


@file naming conventions
\M{File naming conventions}
\T{File naming conventions:}

Each job should be assigned a unique file name, with the 
individual data files differing only in the file name 
suffix.

\B{.SCH}:~~Recommended name suffix for single sheet schematic 
data files.  For multi-sheet schematics, you should start with 
.SH1 for the first file and increment the number in the suffix 
for each of the following sheets.  If the schematic is to 
distributed over more that 9 sheets, you should start with 
.S01 for the first file.

\B{.PCB}:~~Recommended name suffix for all printed circuit board 
data files.

\B{.NET}:~~Recommended name suffix for the netlist output file 
from single sheet schematic.  For multi-sheet schematics, the 
netlist file will retain the same number as the source file 
(.NT1 for .SH1 or .N01 for .S01).

\B{.LOG}:~~A error log file is produced automatically whenever 
a \S{Netlist In} function is performed.

\B{.BOM}:~~Recommended name suffix for all bill of materials 
data files.

\B{.PCL}:~~Recommended name suffix for all printer control 
language data files.

\B{.HPG}:~~Recommended name suffix for all HPGL plot files.

\B{.DXF}:~~Required name suffix for all Autocad \S{DXF} files.

\B{.LIB}:~~Recommended name suffix for all library data files.


@reserved file names
\M{Reserved file names}
\T{Reserved file names:}

All reserved files carry the name \B{CIRCAD.xxx}, most of which 
are hidden away in three sub-directories.

\B{CIRCAD.COM}:~~An executable code module containing the 
multi-tasking kernel, the interrupt routines, the main task, the 
mouse/keyboard task, the standard I/O routines, and all the basic 
graphics editing routines.

\B{CIRCAD.INI}:~~Initialization data file.  An \S{ASCII} text 
file containing commands to establish the basic working 
environment for the various processes.  This file is read in and 
decoded before any processing begins.

\S{CIRCAD.DRV}:~~Subdirectory containing auxiliary code modules, 
hardware device drivers, and related data files.

\S{CIRCAD.LIB}:~~Subdirectory containing library files used 
by the \S{Place Component} function.

\S{CIRCAD.TPL}:~~Subdirectory containing template files used 
by the \S{New File} function.


@driver subdirectory
@CIRCAD.DRV
\M{Driver Directory}
\T{Driver Directory:}

\B{CIRCAD.CCB}:~~Executable code module containing the 
background clean-up and garbage collection task.

\B{CIRCAD.CCD}:~~Executable code module containing the generic 
drawing routines for lines, arcs, pads, and text strings.

\B{CIRCAD.CCI}:~~Executable code module for system initialization.

\B{CIRCAD.CCW}:~~Executable code module containing the windows 
processing routines and their subroutines.

\B{CIRCAD.CGT}:~~Binary file containing the character generation 
tables used to stroke out the \S{ASCII} characters.

\B{CIRCAD.MAN}:~~ASCII file containing the basic data 
for the hypertext reference manual sub-system.

\B{CIRCAD.MSG}:~~ASCII file containing the messages for the 
status line at the bottom of the graphics screen.

\B{CIRCAD.PPB}:~~Selectable plotting driver for a color PCL 
printer at 150 dpi.

\B{CIRCAD.PPC}:~~Selectable plotting driver for a color PCL 
printer at 300 dpi.

\B{CIRCAD.PPD}:~~Selectable plotting driver for a color PCL 
printer at 600 dpi.

\B{CIRCAD.PPE}:~~Selectable plotting driver for a Cannon color 
bubble jet printer at 180 dpi.

\B{CIRCAD.PPF}:~~Selectable plotting driver for a Cannon color 
bubble jet printer at 360 dpi.

\B{CIRCAD.PPG}:~~Selectable plotting driver for a Cannon color 
bubble jet printer at 720 dpi.

\B{CIRCAD.PPI}:~~Selectable plotting driver for a grey scale PCL 
graphics printer at 150.

\B{CIRCAD.PPJ}:~~Selectable plotting driver for a grey scale PCL 
graphics printer at 300 dpi.

\B{CIRCAD.PPK}:~~Selectable plotting driver for a grey scale PCL 
graphics printer at 600 dpi.

\B{CIRCAD.PPL}:~~Selectable plotting driver for \S{PCX} data 
files.

\B{CIRCAD.PPQ}:~~Selectable plotting driver for a 24 pin Epson 
printer at 180 dpi.  Also useful for a B/W Cannon bubble jet.

\B{CIRCAD.PPR}:~~Selectable plotting driver for a B/W Cannon 
bubble jet printer at 360 dpi.

\B{CIRCAD.PPS}:~~Selectable plotting driver for postscript 
printers.

\B{CIRCAD.PPU}:~~Selectable plotting driver for a DMPL vector 
plotter.

\B{CIRCAD.PPV}:~~Selectable plotting driver for a generic vector 
plotter.

\B{CIRCAD.PPW}:~~Selectable plotting driver for a HPGL vector 
plotter.

\B{CIRCAD.PPX}:~~Selectable plotting driver for a 9 pin Epson 
printer.

\B{CIRCAD.SGG}:~~ASCII file containing setup commands for the 
Gerber import and export filters.

\B{CIRCAD.SPB}:~~ASCII file containing setup commands for a 
color 150 dpi PCL graphics printer.

\B{CIRCAD.SPC}:~~ASCII file containing setup commands for a 
color 300 dpi PCL graphics printer.

\B{CIRCAD.SPD}:~~ASCII file containing setup commands for a 
color 600 dpi PCL graphics printer.

\B{CIRCAD.SPE}:~~ASCII file containing setup commands for a 
color 180 dpi Cannon Bubble Jet printer.

\B{CIRCAD.SPF}:~~ASCII file containing setup commands for a 
color 360 dpi Cannon Bubble Jet printer.

\B{CIRCAD.SPG}:~~ASCII file containing setup commands for a 
color 720 dpi Cannon Bubble Jet printer.

\B{CIRCAD.SPI}:~~ASCII file containing setup commands for a 
150 dpi grey scale PCL graphics printer.

\B{CIRCAD.SPJ}:~~ASCII file containing setup commands for a 
300 dpi grey scale PCL graphics printer.

\B{CIRCAD.SPK}:~~ASCII file containing setup commands for a 
600 dpi grey scale PCL graphics printer.

\B{CIRCAD.SPL}:~~ASCII file containing setup commands for PCX 
file plotting.

\B{CIRCAD.SPQ}:~~ASCII file containing setup commands for a 
180 dpi 24 pin graphics printer.

\B{CIRCAD.SPR}:~~ASCII file containing setup commands for a 
360 dpi 48 pin graphics printer.

\B{CIRCAD.SPS}:~~ASCII file containing setup commands for 
PostScript plotting.

\B{CIRCAD.SPU}:~~ASCII file containing setup commands for a 
vector plotter using DMPL.

\B{CIRCAD.SPV}:~~ASCII file containing setup commands for a 
generic vector plotter.  The target language can be customized.

\B{CIRCAD.SPW}:~~ASCII file containing setup commands for a 
vector plotter using HPGL.

\B{CIRCAD.SPX}:~~ASCII file containing setup commands for a 
9 pin Epson graphics printer.

\B{CIRCAD.VGA}:~~Selectable video driver for a 640x480 VGA 
display.

\B{CIRCAD.VGH}:~~Selectable video driver for a 1024x768 SVGA 
display.

\B{CIRCAD.VGM}:~~Selectable video driver for an 800x600 SVGA 
display.

\B{CIRCAD.WIN}:~~ASCII file containing the basic data for the 
windowing sub-system.

\B{CIRCAD.XBO}:~~Transient code module for bill of materials 
output function.

\B{CIRCAD.XFF}:~~Transient code module for flood, hatch, and 
outline fill functions.

\B{CIRCAD.XFI}:~~Transient code module for import filter 
subroutines.

\B{CIRCAD.XFO}:~~Transient code module for export filter
subroutines.

\B{CIRCAD.XGG}:~~Transient code module for Gerber output 
function.

\B{CIRCAD.XJF}:~~Transient code module for screen snapshot 
function.

\B{CIRCAD.XLI}:~~Transient code module for source library input 
subroutines.

\B{CIRCAD.XNI}:~~Transient code module for netlist input 
function.

\B{CIRCAD.XNO}:~~Transient code module for netlist output 
function.

\B{CIRCAD.XNW}:~~Transient code module for wirelist output 
function.

\B{CIRCAD.XPO}:~~Transient code module for plotter status save 
subroutines.

\B{CIRCAD.XRT}:~~Transient code module for autorouter functions.

\B{CIRCAD.XSF}:~~Transient code module for script file startup 
and macro key load/save functions.

\B{CIRCAD.XXA}:~~Transient code module for pixel image scanner 
input function.

\B{CIRCAD.XXI}:~~Transient code module for pixel image file 
import function.

\B{CIRCAD.XXX}:~~Transient code module for screen pixel image 
control functions.


@library subdirectory
@CIRCAD.LIB
\M{Library Directory}
\T{Library Directory:}

\B{ANALOG.LIB}:~~Schematic library file for analog and linear 
devices.

\B{CMOS.LIB}:~~Schematic library file for CMOS devices.

\B{DISCRETE.LIB}:~~Schematic library file for discrete devices 
such as resistors, capacitors, diodes, and transistors.

\B{ECL.LIB}:~~Schematic library file for ECL devices.

\B{MEMORY.LIB}:~~Schematic library file for RAMs, ROMs, and PROMs.

\B{MICRO.LIB}:~~Schematic library file for microcomputers and 
microprocessors.

\B{PLD.LIB}:~~Schematic library file for PALs and GALs.

\B{TTL.LIB}:~~Schematic library file for TTL devices.

\B{THD.LIB}:~~PCB library file for through hole devices.

\B{SMD.LIB}:~~PCB library file for surface mount devices.

\B{PCB.LIB}:~~Sample of a graphics image library for PCBs.

\B{SCH.LIB}:~~Sample of a graphics image library for schematics.


@template subdirectory
@CIRCAD.TPL
\M{Template Directory}
\T{Template Directory:}

\L{\B{CIRCAD.TPA}:~~Template for PCB size A.}
\L{\B{CIRCAD.TPB}:~~Template for PCB size B.}
\L{\B{CIRCAD.TPC}:~~Template for PCB size C.}
\L{\B{CIRCAD.TPD}:~~Template for PCB size D.}

\L{\B{CIRCAD.TSA}:~~Template for schematic size A.}
\L{\B{CIRCAD.TSB}:~~Template for schematic size B.}
\L{\B{CIRCAD.TSC}:~~Template for schematic size C.}
\L{\B{CIRCAD.TSD}:~~Template for schematic size D.}

\L{\B{CIRCAD.TDA}:~~Template for drawing size A.}
\L{\B{CIRCAD.TDB}:~~Template for drawing size B.}
\L{\B{CIRCAD.TDC}:~~Template for drawing size C.}
\L{\B{CIRCAD.TDD}:~~Template for drawing size D.}


@CIRCAD
\M{CIRCAD Trade Mark}
\T{CIRCAD} is a U.S\. registered trade mark of:

\L{  \B{Holophase Incorporated}}
\L{  \B{6191 Orange Drive}}
\L{  \B{Suite 6163-G}}
\L{  \B{Davie Florida  33314}}
\L{~}
\L{All rights reserved.}
\L{~}

You may contact us at:

\L{  \B{Sales:&(954) 584-0010}}
\L{  \B{Tech:&(954) 584-5123}}
\L{  \B{Fax:&(954) 584-5972}}
\L{  \B{BBS:&(954) 584-7089}}


@DXF
@DXF files
\M{DXF files}
\T{DXF file translation:}

DXF stands for \B{D}RAWING E\B{X}CHANGE \B{F}ORMAT.  The format was 
first concocted by the authors of AutoCAD to help promote drawing file 
translation to and from other software packages.  Although the 
encoding scheme is both verbose and cryptic, its complete format 
has been published and thus is universally accepted.

CIRCAD's transparent import filtering allows you to read a DXF 
file by simply selecting the desired file when using the 
\S{Open File} function.

To write a DXF file, you must explicitly specify DXF format when 
using the \S{Save As ...} function.


@RS-274-D
@Gerber format
\M{EIA RS-274-D}
\T{RS-274-D} is the technical name for \B{Gerber} \B{Format}, which is 
the industry standard photo plotting language.  The designation 
\B{RS-274-X} is sometimes [incorrectly] used to refer to this 
language format.

The format was first introduced in 1980, and has been upgraded 
several times since then.  The most significant enhancement was 
the addition of embedded aperture codes in early 1991.  This 
feature allows each file to be completely self defining, needing 
no other accompanying documents for processing.  \S{CIRCAD} 
utilizes embedded aperture codes in all its Gerber output files.

A complete document describing Gerber format is available for 
\$35 from:

\L{  \B{Bob Layton}}
\L{  \B{Gerber Systems Corporation}}
\L{  \B{83 Gerber Road West}}
\L{  \B{South Windsor CT  06074}}
\L{  \B{(203) 644-1551}}


@ASCII
\M{ASCII}
\T{ASCII:}

The \B{A}merican \B{S}tandard \B{C}ode for \B{I}nformation 
\B{I}nterchange is the name of a mapping sequence for 
representing numbers, letters and symbols.  An ASCII text 
file is a file that can be intelligibly displayed on the 
video screen or printed on paper.

\S{CIRCAD} uses the ASCII character set with a few additional 
\S{special characters} that are useful as engineering symbols.  
These additional characters comply with the IBM 
\S{Extended ASCII} Character Set whenever possible.


@ASCII Extended
@Extended ASCII
\M{Extended ASCII}
\T{CIRCAD Extended ASCII:}

\L{    \220 0\180 1\180 2\180 3\180 4\180 5\180 6\180 7\180 8\180 9\180 A\179 B\179 C\179 D\179 E\179 F\223}
\L{0   ~\180\1\178\2\178\3\178\4\178\5\178\6\178\7\178\8\178\9\178\10\178\11\178\12\178\13\178\14\178\15}
\L{1   \16\178\17\178\18\178\19\178\20\178\21\178\22\178\23\178\24\181\25\181\26\179\27\179\28\178\29\178\30\178\31}
\L{2   ~\181 !\182 "\181 #\179\$\179\%\179\&\179 '\182 (\182 )\182 *\179 +\179 ,\182 -\180 .\182 /}
\L{3   0\180 1\180 2\180 3\180 4\180 5\180 6\180 7\180 8\180 9\180 :\182 ;\182 <\180 =\179 >\180 ?}
\L{4   ~\180 A\179 B\179 C\179 D\179 E\179 F\179 G\179 H\180 I\180 J\179 K\179 L\179 M\179 N\179 O}
\L{5   P\179 Q\179 R\179 S\179 T\179 U\179 V\178 W\178 X\179 Y\179 Z\179 [\181\\\179 ]\181 ^\179 _}
\L{6   `\182 a\179 b\179 c\179 d\179 e\179 f\179 g\179 h\180 i\182 j\180 k\180 l\182 m\179 n\180 o}
\L{7   p\179 q\179 r\179 s\179 t\179 u\180 v\179 w\179 x\179 y\179 z\179\{\182 |\182\}\181\~}
\L{8 \180 ---------------- Reserved ----------------}
%\L{8   \178 \178 \178 \178 \178 \178 \178 \178 \178 \178 \178 \178 \178 \178 \178 }
\L{9   \178 \178 \178 \178 \178 \178 \178 \178 \178 \178 \178 \178 \178 \178 \178 }
\L{A \180 \178 \178 \178 \178 \178 \178 \178 \178 \178 \178 \179 \179 \179 \178 \178 }
\L{B \180 ---------------- Reserved ----------------}
\L{C \180 ---------------- Reserved ----------------}
\L{D \182\222 \208\185 \209\185 \210\185 \211\185 \212\185 \213\185 \214\185 \215\185 \216\185 \217\222\187 \218\185 \219\223}
\L{E \180 \179 \180 \180 \179 \179 \179 \179 \178 \178 \180 \179 \178 \178 \178 \178 }
\L{F \180 \179 \180 \180 \180 \180 \178 \180 \180 \181 \178 \178 \178 \178 }


@@
